@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -6,6 +7,4 @@ Package contains pure python neuroimaging algorithms
 Exaples: artifactdetect
 
 """
-__docformat__ = 'restructuredtext'
-
-
+__docformat__ = "restructuredtext"
