@@ -1,14 +1,10 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-'''
+"""
 Image assessment algorithms. Typical overlap and error computation
 measures to evaluate results from other processing units.
-'''
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import zip, range
-
+"""
 import os
 import os.path as op
 
@@ -18,23 +14,27 @@ import numpy as np
 from .. import config, logging
 
 from ..interfaces.base import (
-    SimpleInterface, BaseInterface, traits, TraitedSpec, File,
-    InputMultiPath, BaseInterfaceInputSpec,
-    isdefined)
+    SimpleInterface,
+    BaseInterface,
+    traits,
+    TraitedSpec,
+    File,
+    InputMultiPath,
+    BaseInterfaceInputSpec,
+    isdefined,
+)
 from ..interfaces.nipy.base import NipyBaseInterface
 
-iflogger = logging.getLogger('nipype.interface')
+iflogger = logging.getLogger("nipype.interface")
 
 
 class DistanceInputSpec(BaseInterfaceInputSpec):
     volume1 = File(
-        exists=True,
-        mandatory=True,
-        desc="Has to have the same dimensions as volume2.")
+        exists=True, mandatory=True, desc="Has to have the same dimensions as volume2."
+    )
     volume2 = File(
-        exists=True,
-        mandatory=True,
-        desc="Has to have the same dimensions as volume1.")
+        exists=True, mandatory=True, desc="Has to have the same dimensions as volume1."
+    )
     method = traits.Enum(
         "eucl_min",
         "eucl_cog",
@@ -50,21 +50,22 @@ class DistanceInputSpec(BaseInterfaceInputSpec):
         to volume1 weighted by their values\
         "eucl_max": maximum over minimum Euclidian distances of all volume2\
         voxels to volume1 (also known as the Hausdorff distance)',
-        usedefault=True)
-    mask_volume = File(
-        exists=True, desc="calculate overlap only within this mask.")
+        usedefault=True,
+    )
+    mask_volume = File(exists=True, desc="calculate overlap only within this mask.")
 
 
 class DistanceOutputSpec(TraitedSpec):
     distance = traits.Float()
-    point1 = traits.Array(shape=(3, ))
-    point2 = traits.Array(shape=(3, ))
+    point1 = traits.Array(shape=(3,))
+    point2 = traits.Array(shape=(3,))
     histogram = File()
 
 
 class Distance(BaseInterface):
     """Calculates distance between two volumes.
     """
+
     input_spec = DistanceInputSpec
     output_spec = DistanceOutputSpec
 
@@ -72,6 +73,7 @@ class Distance(BaseInterface):
 
     def _find_border(self, data):
         from scipy.ndimage.morphology import binary_erosion
+
         eroded = binary_erosion(data)
         border = np.logical_and(data, np.logical_not(eroded))
         return border
@@ -86,10 +88,11 @@ class Distance(BaseInterface):
 
     def _eucl_min(self, nii1, nii2):
         from scipy.spatial.distance import cdist, euclidean
-        origdata1 = nii1.get_data().astype(np.bool)
+
+        origdata1 = np.asanyarray(nii1.dataobj).astype(np.bool)
         border1 = self._find_border(origdata1)
 
-        origdata2 = nii2.get_data().astype(np.bool)
+        origdata2 = np.asanyarray(nii2.dataobj).astype(np.bool)
         border2 = self._find_border(origdata2)
 
         set1_coordinates = self._get_coordinates(border1, nii1.affine)
@@ -97,30 +100,31 @@ class Distance(BaseInterface):
         set2_coordinates = self._get_coordinates(border2, nii2.affine)
 
         dist_matrix = cdist(set1_coordinates.T, set2_coordinates.T)
-        (point1, point2) = np.unravel_index(
-            np.argmin(dist_matrix), dist_matrix.shape)
-        return (euclidean(set1_coordinates.T[point1, :],
-                          set2_coordinates.T[point2, :]),
-                set1_coordinates.T[point1, :], set2_coordinates.T[point2, :])
+        (point1, point2) = np.unravel_index(np.argmin(dist_matrix), dist_matrix.shape)
+        return (
+            euclidean(set1_coordinates.T[point1, :], set2_coordinates.T[point2, :]),
+            set1_coordinates.T[point1, :],
+            set2_coordinates.T[point2, :],
+        )
 
     def _eucl_cog(self, nii1, nii2):
         from scipy.spatial.distance import cdist
         from scipy.ndimage.measurements import center_of_mass, label
-        origdata1 = np.logical_and(nii1.get_data() != 0,
-                                   np.logical_not(np.isnan(nii1.get_data())))
-        cog_t = np.array(center_of_mass(origdata1.copy())).reshape(-1, 1)
+
+        origdata1 = np.asanyarray(nii1.dataobj)
+        origdata1 = (np.rint(origdata1) != 0) & ~np.isnan(origdata1)
+        cog_t = np.array(center_of_mass(origdata1)).reshape(-1, 1)
         cog_t = np.vstack((cog_t, np.array([1])))
         cog_t_coor = np.dot(nii1.affine, cog_t)[:3, :]
 
-        origdata2 = np.logical_and(nii2.get_data() != 0,
-                                   np.logical_not(np.isnan(nii2.get_data())))
+        origdata2 = np.asanyarray(nii2.dataobj)
+        origdata2 = (np.rint(origdata2) != 0) & ~np.isnan(origdata2)
         (labeled_data, n_labels) = label(origdata2)
 
         cogs = np.ones((4, n_labels))
 
         for i in range(n_labels):
-            cogs[:3, i] = np.array(
-                center_of_mass(origdata2, labeled_data, i + 1))
+            cogs[:3, i] = np.array(center_of_mass(origdata2, labeled_data, i + 1))
 
         cogs_coor = np.dot(nii2.affine, cogs)[:3, :]
 
@@ -130,10 +134,11 @@ class Distance(BaseInterface):
 
     def _eucl_mean(self, nii1, nii2, weighted=False):
         from scipy.spatial.distance import cdist
-        origdata1 = nii1.get_data().astype(np.bool)
+
+        origdata1 = np.asanyarray(nii1.dataobj).astype(np.bool)
         border1 = self._find_border(origdata1)
 
-        origdata2 = nii2.get_data().astype(np.bool)
+        origdata2 = np.asanyarray(nii2.dataobj).astype(np.bool)
 
         set1_coordinates = self._get_coordinates(border1, nii1.affine)
         set2_coordinates = self._get_coordinates(origdata2, nii2.affine)
@@ -141,38 +146,37 @@ class Distance(BaseInterface):
         dist_matrix = cdist(set1_coordinates.T, set2_coordinates.T)
         min_dist_matrix = np.amin(dist_matrix, axis=0)
         import matplotlib
-        matplotlib.use(config.get('execution', 'matplotlib_backend'))
+
+        matplotlib.use(config.get("execution", "matplotlib_backend"))
         import matplotlib.pyplot as plt
+
         plt.figure()
-        plt.hist(min_dist_matrix, 50, normed=1, facecolor='green')
+        plt.hist(min_dist_matrix, 50, normed=1, facecolor="green")
         plt.savefig(self._hist_filename)
         plt.clf()
         plt.close()
 
         if weighted:
-            return np.average(
-                min_dist_matrix, weights=nii2.get_data()[origdata2].flat)
+            return np.average(min_dist_matrix, weights=nii2.dataobj[origdata2].flat)
         else:
             return np.mean(min_dist_matrix)
 
     def _eucl_max(self, nii1, nii2):
         from scipy.spatial.distance import cdist
-        origdata1 = nii1.get_data()
-        origdata1 = np.logical_not(
-            np.logical_or(origdata1 == 0, np.isnan(origdata1)))
-        origdata2 = nii2.get_data()
-        origdata2 = np.logical_not(
-            np.logical_or(origdata2 == 0, np.isnan(origdata2)))
+
+        origdata1 = np.asanyarray(nii1.dataobj)
+        origdata1 = (np.rint(origdata1) != 0) & ~np.isnan(origdata1)
+        origdata2 = np.asanyarray(nii2.dataobj)
+        origdata2 = (np.rint(origdata2) != 0) & ~np.isnan(origdata2)
 
         if isdefined(self.inputs.mask_volume):
-            maskdata = nb.load(self.inputs.mask_volume).get_data()
-            maskdata = np.logical_not(
-                np.logical_or(maskdata == 0, np.isnan(maskdata)))
+            maskdata = np.asanyarray(nb.load(self.inputs.mask_volume).dataobj)
+            maskdata = (np.rint(maskdata) != 0) & ~np.isnan(maskdata)
             origdata1 = np.logical_and(maskdata, origdata1)
             origdata2 = np.logical_and(maskdata, origdata2)
 
         if origdata1.max() == 0 or origdata2.max() == 0:
-            return np.NaN
+            return np.nan
 
         border1 = self._find_border(origdata1)
         border2 = self._find_border(origdata2)
@@ -180,8 +184,7 @@ class Distance(BaseInterface):
         set1_coordinates = self._get_coordinates(border1, nii1.affine)
         set2_coordinates = self._get_coordinates(border2, nii2.affine)
         distances = cdist(set1_coordinates.T, set2_coordinates.T)
-        mins = np.concatenate((np.amin(distances, axis=0),
-                               np.amin(distances, axis=1)))
+        mins = np.concatenate((np.amin(distances, axis=0), np.amin(distances, axis=1)))
 
         return np.max(mins)
 
@@ -191,8 +194,7 @@ class Distance(BaseInterface):
         nii2 = nb.load(self.inputs.volume2, mmap=False)
 
         if self.inputs.method == "eucl_min":
-            self._distance, self._point1, self._point2 = self._eucl_min(
-                nii1, nii2)
+            self._distance, self._point1, self._point2 = self._eucl_min(nii1, nii2)
 
         elif self.inputs.method == "eucl_cog":
             self._distance = self._eucl_cog(nii1, nii2)
@@ -209,62 +211,55 @@ class Distance(BaseInterface):
 
     def _list_outputs(self):
         outputs = self._outputs().get()
-        outputs['distance'] = self._distance
+        outputs["distance"] = self._distance
         if self.inputs.method == "eucl_min":
-            outputs['point1'] = self._point1
-            outputs['point2'] = self._point2
+            outputs["point1"] = self._point1
+            outputs["point2"] = self._point2
         elif self.inputs.method in ["eucl_mean", "eucl_wmean"]:
-            outputs['histogram'] = os.path.abspath(self._hist_filename)
+            outputs["histogram"] = os.path.abspath(self._hist_filename)
         return outputs
 
 
 class OverlapInputSpec(BaseInterfaceInputSpec):
     volume1 = File(
-        exists=True,
-        mandatory=True,
-        desc='Has to have the same dimensions as volume2.')
+        exists=True, mandatory=True, desc="Has to have the same dimensions as volume2."
+    )
     volume2 = File(
-        exists=True,
-        mandatory=True,
-        desc='Has to have the same dimensions as volume1.')
-    mask_volume = File(
-        exists=True, desc='calculate overlap only within this mask.')
+        exists=True, mandatory=True, desc="Has to have the same dimensions as volume1."
+    )
+    mask_volume = File(exists=True, desc="calculate overlap only within this mask.")
     bg_overlap = traits.Bool(
-        False,
-        usedefault=True,
-        mandatory=True,
-        desc='consider zeros as a label')
-    out_file = File('diff.nii', usedefault=True)
+        False, usedefault=True, mandatory=True, desc="consider zeros as a label"
+    )
+    out_file = File("diff.nii", usedefault=True)
     weighting = traits.Enum(
-        'none',
-        'volume',
-        'squared_vol',
+        "none",
+        "volume",
+        "squared_vol",
         usedefault=True,
-        desc=('\'none\': no class-overlap weighting is '
-              'performed. \'volume\': computed class-'
-              'overlaps are weighted by class volume '
-              '\'squared_vol\': computed class-overlaps '
-              'are weighted by the squared volume of '
-              'the class'))
+        desc=(
+            "'none': no class-overlap weighting is "
+            "performed. 'volume': computed class-"
+            "overlaps are weighted by class volume "
+            "'squared_vol': computed class-overlaps "
+            "are weighted by the squared volume of "
+            "the class"
+        ),
+    )
     vol_units = traits.Enum(
-        'voxel',
-        'mm',
-        mandatory=True,
-        usedefault=True,
-        desc='units for volumes')
+        "voxel", "mm", mandatory=True, usedefault=True, desc="units for volumes"
+    )
 
 
 class OverlapOutputSpec(TraitedSpec):
-    jaccard = traits.Float(desc='averaged jaccard index')
-    dice = traits.Float(desc='averaged dice index')
-    roi_ji = traits.List(
-        traits.Float(), desc=('the Jaccard index (JI) per ROI'))
-    roi_di = traits.List(traits.Float(), desc=('the Dice index (DI) per ROI'))
-    volume_difference = traits.Float(desc=('averaged volume difference'))
-    roi_voldiff = traits.List(
-        traits.Float(), desc=('volume differences of ROIs'))
-    labels = traits.List(traits.Int(), desc=('detected labels'))
-    diff_file = File(exists=True, desc='error map of differences')
+    jaccard = traits.Float(desc="averaged jaccard index")
+    dice = traits.Float(desc="averaged dice index")
+    roi_ji = traits.List(traits.Float(), desc=("the Jaccard index (JI) per ROI"))
+    roi_di = traits.List(traits.Float(), desc=("the Dice index (DI) per ROI"))
+    volume_difference = traits.Float(desc=("averaged volume difference"))
+    roi_voldiff = traits.List(traits.Float(), desc=("volume differences of ROIs"))
+    labels = traits.List(traits.Int(), desc=("detected labels"))
+    diff_file = File(exists=True, desc="error map of differences")
 
 
 class Overlap(BaseInterface):
@@ -286,12 +281,14 @@ class Overlap(BaseInterface):
     >>> res = overlap.run() # doctest: +SKIP
 
     """
+
     input_spec = OverlapInputSpec
     output_spec = OverlapOutputSpec
 
     def _bool_vec_dissimilarity(self, booldata1, booldata2, method):
         from scipy.spatial.distance import dice, jaccard
-        methods = {'dice': dice, 'jaccard': jaccard}
+
+        methods = {"dice": dice, "jaccard": jaccard}
         if not (np.any(booldata1) or np.any(booldata2)):
             return 0
         return 1 - methods[method](booldata1.flat, booldata2.flat)
@@ -302,20 +299,18 @@ class Overlap(BaseInterface):
 
         scale = 1.0
 
-        if self.inputs.vol_units == 'mm':
-            voxvol = nii1.header.get_zooms()
-            for i in range(nii1.get_data().ndim - 1):
-                scale = scale * voxvol[i]
+        if self.inputs.vol_units == "mm":
+            scale = np.prod(nii1.header.get_zooms()[:3])
 
-        data1 = nii1.get_data()
+        data1 = np.asanyarray(nii1.dataobj)
         data1[np.logical_or(data1 < 0, np.isnan(data1))] = 0
         max1 = int(data1.max())
         data1 = data1.astype(np.min_scalar_type(max1))
-        data2 = nii2.get_data().astype(np.min_scalar_type(max1))
+        data2 = np.asanyarray(nii2.dataobj).astype(np.min_scalar_type(max1))
         data2[np.logical_or(data1 < 0, np.isnan(data1))] = 0
 
         if isdefined(self.inputs.mask_volume):
-            maskdata = nb.load(self.inputs.mask_volume).get_data()
+            maskdata = np.asanyarray(nb.load(self.inputs.mask_volume).dataobj)
             maskdata = ~np.logical_or(maskdata == 0, np.isnan(maskdata))
             data1[~maskdata] = 0
             data2[~maskdata] = 0
@@ -330,51 +325,50 @@ class Overlap(BaseInterface):
 
         for l in labels:
             res.append(
-                self._bool_vec_dissimilarity(
-                    data1 == l, data2 == l, method='jaccard'))
+                self._bool_vec_dissimilarity(data1 == l, data2 == l, method="jaccard")
+            )
             volumes1.append(scale * len(data1[data1 == l]))
             volumes2.append(scale * len(data2[data2 == l]))
 
         results = dict(jaccard=[], dice=[])
-        results['jaccard'] = np.array(res)
-        results['dice'] = 2.0 * results['jaccard'] / (results['jaccard'] + 1.0)
+        results["jaccard"] = np.array(res)
+        results["dice"] = 2.0 * results["jaccard"] / (results["jaccard"] + 1.0)
 
-        weights = np.ones((len(volumes1), ), dtype=np.float32)
-        if self.inputs.weighting != 'none':
+        weights = np.ones((len(volumes1),), dtype=np.float32)
+        if self.inputs.weighting != "none":
             weights = weights / np.array(volumes1)
-            if self.inputs.weighting == 'squared_vol':
-                weights = weights**2
+            if self.inputs.weighting == "squared_vol":
+                weights = weights ** 2
         weights = weights / np.sum(weights)
 
         both_data = np.zeros(data1.shape)
         both_data[(data1 - data2) != 0] = 1
 
         nb.save(
-            nb.Nifti1Image(both_data, nii1.affine, nii1.header),
-            self.inputs.out_file)
+            nb.Nifti1Image(both_data, nii1.affine, nii1.header), self.inputs.out_file
+        )
 
         self._labels = labels
         self._ove_rois = results
-        self._vol_rois = (
-            np.array(volumes1) - np.array(volumes2)) / np.array(volumes1)
+        self._vol_rois = (np.array(volumes1) - np.array(volumes2)) / np.array(volumes1)
 
-        self._dice = round(np.sum(weights * results['dice']), 5)
-        self._jaccard = round(np.sum(weights * results['jaccard']), 5)
+        self._dice = round(np.sum(weights * results["dice"]), 5)
+        self._jaccard = round(np.sum(weights * results["jaccard"]), 5)
         self._volume = np.sum(weights * self._vol_rois)
 
         return runtime
 
     def _list_outputs(self):
         outputs = self._outputs().get()
-        outputs['labels'] = self._labels
-        outputs['jaccard'] = self._jaccard
-        outputs['dice'] = self._dice
-        outputs['volume_difference'] = self._volume
+        outputs["labels"] = self._labels
+        outputs["jaccard"] = self._jaccard
+        outputs["dice"] = self._dice
+        outputs["volume_difference"] = self._volume
 
-        outputs['roi_ji'] = self._ove_rois['jaccard'].tolist()
-        outputs['roi_di'] = self._ove_rois['dice'].tolist()
-        outputs['roi_voldiff'] = self._vol_rois.tolist()
-        outputs['diff_file'] = os.path.abspath(self.inputs.out_file)
+        outputs["roi_ji"] = self._ove_rois["jaccard"].tolist()
+        outputs["roi_di"] = self._ove_rois["dice"].tolist()
+        outputs["roi_voldiff"] = self._vol_rois.tolist()
+        outputs["diff_file"] = os.path.abspath(self.inputs.out_file)
         return outputs
 
 
@@ -382,38 +376,44 @@ class FuzzyOverlapInputSpec(BaseInterfaceInputSpec):
     in_ref = InputMultiPath(
         File(exists=True),
         mandatory=True,
-        desc='Reference image. Requires the same dimensions as in_tst.')
+        desc="Reference image. Requires the same dimensions as in_tst.",
+    )
     in_tst = InputMultiPath(
         File(exists=True),
         mandatory=True,
-        desc='Test image. Requires the same dimensions as in_ref.')
-    in_mask = File(exists=True, desc='calculate overlap only within mask')
+        desc="Test image. Requires the same dimensions as in_ref.",
+    )
+    in_mask = File(exists=True, desc="calculate overlap only within mask")
     weighting = traits.Enum(
-        'none',
-        'volume',
-        'squared_vol',
+        "none",
+        "volume",
+        "squared_vol",
         usedefault=True,
-        desc=('\'none\': no class-overlap weighting is '
-              'performed. \'volume\': computed class-'
-              'overlaps are weighted by class volume '
-              '\'squared_vol\': computed class-overlaps '
-              'are weighted by the squared volume of '
-              'the class'))
+        desc=(
+            "'none': no class-overlap weighting is "
+            "performed. 'volume': computed class-"
+            "overlaps are weighted by class volume "
+            "'squared_vol': computed class-overlaps "
+            "are weighted by the squared volume of "
+            "the class"
+        ),
+    )
     out_file = File(
-        'diff.nii',
-        desc='alternative name for resulting difference-map',
-        usedefault=True)
+        "diff.nii",
+        desc="alternative name for resulting difference-map",
+        usedefault=True,
+    )
 
 
 class FuzzyOverlapOutputSpec(TraitedSpec):
-    jaccard = traits.Float(desc='Fuzzy Jaccard Index (fJI), all the classes')
-    dice = traits.Float(desc='Fuzzy Dice Index (fDI), all the classes')
+    jaccard = traits.Float(desc="Fuzzy Jaccard Index (fJI), all the classes")
+    dice = traits.Float(desc="Fuzzy Dice Index (fDI), all the classes")
     class_fji = traits.List(
-        traits.Float(),
-        desc='Array containing the fJIs of each computed class')
+        traits.Float(), desc="Array containing the fJIs of each computed class"
+    )
     class_fdi = traits.List(
-        traits.Float(),
-        desc='Array containing the fDIs of each computed class')
+        traits.Float(), desc="Array containing the fDIs of each computed class"
+    )
 
 
 class FuzzyOverlap(SimpleInterface):
@@ -441,22 +441,22 @@ class FuzzyOverlap(SimpleInterface):
 
     def _run_interface(self, runtime):
         # Load data
-        refdata = nb.concat_images(self.inputs.in_ref).get_data()
-        tstdata = nb.concat_images(self.inputs.in_tst).get_data()
+        refdata = nb.concat_images(self.inputs.in_ref).dataobj
+        tstdata = nb.concat_images(self.inputs.in_tst).dataobj
 
         # Data must have same shape
         if not refdata.shape == tstdata.shape:
             raise RuntimeError(
-                'Size of "in_tst" %s must match that of "in_ref" %s.' %
-                (tstdata.shape, refdata.shape))
+                'Size of "in_tst" %s must match that of "in_ref" %s.'
+                % (tstdata.shape, refdata.shape)
+            )
 
         ncomp = refdata.shape[-1]
 
         # Load mask
         mask = np.ones_like(refdata, dtype=bool)
         if isdefined(self.inputs.in_mask):
-            mask = nb.load(self.inputs.in_mask).get_data()
-            mask = mask > 0
+            mask = np.asanyarray(nb.load(self.inputs.in_mask).dataobj) > 0
             mask = np.repeat(mask[..., np.newaxis], ncomp, -1)
             assert mask.shape == refdata.shape
 
@@ -465,29 +465,33 @@ class FuzzyOverlap(SimpleInterface):
         tstdata = tstdata[mask]
 
         if np.any(refdata < 0.0):
-            iflogger.warning('Negative values encountered in "in_ref" input, '
-                             'taking absolute values.')
+            iflogger.warning(
+                'Negative values encountered in "in_ref" input, '
+                "taking absolute values."
+            )
             refdata = np.abs(refdata)
 
         if np.any(tstdata < 0.0):
-            iflogger.warning('Negative values encountered in "in_tst" input, '
-                             'taking absolute values.')
+            iflogger.warning(
+                'Negative values encountered in "in_tst" input, '
+                "taking absolute values."
+            )
             tstdata = np.abs(tstdata)
 
         if np.any(refdata > 1.0):
-            iflogger.warning('Values greater than 1.0 found in "in_ref" input, '
-                             'scaling values.')
+            iflogger.warning(
+                'Values greater than 1.0 found in "in_ref" input, ' "scaling values."
+            )
             refdata /= refdata.max()
 
         if np.any(tstdata > 1.0):
-            iflogger.warning('Values greater than 1.0 found in "in_tst" input, '
-                             'scaling values.')
+            iflogger.warning(
+                'Values greater than 1.0 found in "in_tst" input, ' "scaling values."
+            )
             tstdata /= tstdata.max()
 
-        numerators = np.atleast_2d(
-            np.minimum(refdata, tstdata).reshape((-1, ncomp)))
-        denominators = np.atleast_2d(
-            np.maximum(refdata, tstdata).reshape((-1, ncomp)))
+        numerators = np.atleast_2d(np.minimum(refdata, tstdata).reshape((-1, ncomp)))
+        denominators = np.atleast_2d(np.maximum(refdata, tstdata).reshape((-1, ncomp)))
 
         jaccards = numerators.sum(axis=0) / denominators.sum(axis=0)
 
@@ -497,16 +501,16 @@ class FuzzyOverlap(SimpleInterface):
             volumes = np.sum((refdata + tstdata) > 0, axis=1).reshape((-1, ncomp))
             weights = 1.0 / volumes
             if self.inputs.weighting == "squared_vol":
-                weights = weights**2
+                weights = weights ** 2
 
         weights = weights / np.sum(weights)
         dices = 2.0 * jaccards / (jaccards + 1.0)
 
         # Fill-in the results object
-        self._results['jaccard'] = float(weights.dot(jaccards))
-        self._results['dice'] = float(weights.dot(dices))
-        self._results['class_fji'] = [float(v) for v in jaccards]
-        self._results['class_fdi'] = [float(v) for v in dices]
+        self._results["jaccard"] = float(weights.dot(jaccards))
+        self._results["dice"] = float(weights.dot(dices))
+        self._results["class_fji"] = [float(v) for v in jaccards]
+        self._results["class_fdi"] = [float(v) for v in dices]
         return runtime
 
 
@@ -514,18 +518,21 @@ class ErrorMapInputSpec(BaseInterfaceInputSpec):
     in_ref = File(
         exists=True,
         mandatory=True,
-        desc="Reference image. Requires the same dimensions as in_tst.")
+        desc="Reference image. Requires the same dimensions as in_tst.",
+    )
     in_tst = File(
         exists=True,
         mandatory=True,
-        desc="Test image. Requires the same dimensions as in_ref.")
+        desc="Test image. Requires the same dimensions as in_ref.",
+    )
     mask = File(exists=True, desc="calculate overlap only within this mask.")
     metric = traits.Enum(
         "sqeuclidean",
         "euclidean",
-        desc='error map metric (as implemented in scipy cdist)',
+        desc="error map metric (as implemented in scipy cdist)",
         usedefault=True,
-        mandatory=True)
+        mandatory=True,
+    )
     out_map = File(desc="Name for the output file")
 
 
@@ -545,31 +552,34 @@ class ErrorMap(BaseInterface):
     >>> errormap.inputs.in_tst = 'cont2.nii'
     >>> res = errormap.run() # doctest: +SKIP
     """
+
     input_spec = ErrorMapInputSpec
     output_spec = ErrorMapOutputSpec
-    _out_file = ''
+    _out_file = ""
 
     def _run_interface(self, runtime):
         # Get two numpy data matrices
         nii_ref = nb.load(self.inputs.in_ref)
-        ref_data = np.squeeze(nii_ref.get_data())
-        tst_data = np.squeeze(nb.load(self.inputs.in_tst).get_data())
-        assert (ref_data.ndim == tst_data.ndim)
+        ref_data = np.squeeze(nii_ref.dataobj)
+        tst_data = np.squeeze(nb.load(self.inputs.in_tst).dataobj)
+        assert ref_data.ndim == tst_data.ndim
 
         # Load mask
         comps = 1
         mapshape = ref_data.shape
 
-        if (ref_data.ndim == 4):
+        if ref_data.ndim == 4:
             comps = ref_data.shape[-1]
             mapshape = ref_data.shape[:-1]
 
         if isdefined(self.inputs.mask):
-            msk = nb.load(self.inputs.mask).get_data()
-            if (mapshape != msk.shape):
-                raise RuntimeError("Mask should match volume shape, \
-                                   mask is %s and volumes are %s" %
-                                   (list(msk.shape), list(mapshape)))
+            msk = np.asanyarray(nb.load(self.inputs.mask).dataobj)
+            if mapshape != msk.shape:
+                raise RuntimeError(
+                    "Mask should match volume shape, \
+                                   mask is %s and volumes are %s"
+                    % (list(msk.shape), list(mapshape))
+                )
         else:
             msk = np.ones(shape=mapshape)
 
@@ -578,51 +588,52 @@ class ErrorMap(BaseInterface):
         msk_idxs = np.where(mskvector == 1)
         refvector = ref_data.reshape(-1, comps)[msk_idxs].astype(np.float32)
         tstvector = tst_data.reshape(-1, comps)[msk_idxs].astype(np.float32)
-        diffvector = (refvector - tstvector)
+        diffvector = refvector - tstvector
 
         # Scale the difference
-        if self.inputs.metric == 'sqeuclidean':
-            errvector = diffvector**2
-            if (comps > 1):
+        if self.inputs.metric == "sqeuclidean":
+            errvector = diffvector ** 2
+            if comps > 1:
                 errvector = np.sum(errvector, axis=1)
             else:
                 errvector = np.squeeze(errvector)
-        elif self.inputs.metric == 'euclidean':
+        elif self.inputs.metric == "euclidean":
             errvector = np.linalg.norm(diffvector, axis=1)
 
         errvectorexp = np.zeros_like(
-            mskvector, dtype=np.float32)  # The default type is uint8
+            mskvector, dtype=np.float32
+        )  # The default type is uint8
         errvectorexp[msk_idxs] = errvector
 
         # Get averaged error
-        self._distance = np.average(
-            errvector)  # Only average the masked voxels
+        self._distance = np.average(errvector)  # Only average the masked voxels
 
         errmap = errvectorexp.reshape(mapshape)
 
         hdr = nii_ref.header.copy()
         hdr.set_data_dtype(np.float32)
-        hdr['data_type'] = 16
+        hdr["data_type"] = 16
         hdr.set_data_shape(mapshape)
 
         if not isdefined(self.inputs.out_map):
             fname, ext = op.splitext(op.basename(self.inputs.in_tst))
-            if ext == '.gz':
+            if ext == ".gz":
                 fname, ext2 = op.splitext(fname)
                 ext = ext2 + ext
             self._out_file = op.abspath(fname + "_errmap" + ext)
         else:
             self._out_file = self.inputs.out_map
 
-        nb.Nifti1Image(errmap.astype(np.float32), nii_ref.affine,
-                       hdr).to_filename(self._out_file)
+        nb.Nifti1Image(errmap.astype(np.float32), nii_ref.affine, hdr).to_filename(
+            self._out_file
+        )
 
         return runtime
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
-        outputs['out_map'] = self._out_file
-        outputs['distance'] = self._distance
+        outputs["out_map"] = self._out_file
+        outputs["distance"] = self._distance
         return outputs
 
 
@@ -632,7 +643,7 @@ class SimilarityInputSpec(BaseInterfaceInputSpec):
     mask1 = File(exists=True, desc="3D volume")
     mask2 = File(exists=True, desc="3D volume")
     metric = traits.Either(
-        traits.Enum('cc', 'cr', 'crl1', 'mi', 'nmi', 'slr'),
+        traits.Enum("cc", "cr", "crl1", "mi", "nmi", "slr"),
         traits.Callable(),
         desc="""str or callable
 Cost-function for assessing image similarity. If a string,
@@ -642,12 +653,14 @@ information, 'nmi': normalized mutual information, 'slr':
 supervised log-likelihood ratio. If a callable, it should
 take a two-dimensional array representing the image joint
 histogram as an input and return a float.""",
-        usedefault=True)
+        usedefault=True,
+    )
 
 
 class SimilarityOutputSpec(TraitedSpec):
     similarity = traits.List(
-        traits.Float(desc="Similarity between volume 1 and 2, frame by frame"))
+        traits.Float(desc="Similarity between volume 1 and 2, frame by frame")
+    )
 
 
 class Similarity(NipyBaseInterface):
@@ -675,13 +688,15 @@ class Similarity(NipyBaseInterface):
     output_spec = SimilarityOutputSpec
 
     def _run_interface(self, runtime):
-        from nipy.algorithms.registration.histogram_registration import HistogramRegistration
+        from nipy.algorithms.registration.histogram_registration import (
+            HistogramRegistration,
+        )
         from nipy.algorithms.registration.affine import Affine
 
         vol1_nii = nb.load(self.inputs.volume1)
         vol2_nii = nb.load(self.inputs.volume2)
 
-        dims = vol1_nii.get_data().ndim
+        dims = len(vol1_nii.shape)
 
         if dims == 3 or dims == 2:
             vols1 = [vol1_nii]
@@ -692,15 +707,16 @@ class Similarity(NipyBaseInterface):
 
         if dims < 2 or dims > 4:
             raise RuntimeError(
-                'Image dimensions not supported (detected %dD file)' % dims)
+                "Image dimensions not supported (detected %dD file)" % dims
+            )
 
         if isdefined(self.inputs.mask1):
-            mask1 = nb.load(self.inputs.mask1).get_data() == 1
+            mask1 = np.asanyarray(nb.load(self.inputs.mask1).dataobj) == 1
         else:
             mask1 = None
 
         if isdefined(self.inputs.mask2):
-            mask2 = nb.load(self.inputs.mask2).get_data() == 1
+            mask2 = np.asanyarray(nb.load(self.inputs.mask2).dataobj) == 1
         else:
             mask2 = None
 
@@ -712,12 +728,13 @@ class Similarity(NipyBaseInterface):
                 to_img=ts2,
                 similarity=self.inputs.metric,
                 from_mask=mask1,
-                to_mask=mask2)
+                to_mask=mask2,
+            )
             self._similarity.append(histreg.eval(Affine()))
 
         return runtime
 
     def _list_outputs(self):
         outputs = self._outputs().get()
-        outputs['similarity'] = self._similarity
+        outputs["similarity"] = self._similarity
         return outputs
