@@ -1,10 +1,9 @@
+# -*- coding: utf-8 -*-
 import numpy as np
-from nipype.testing import assert_true
-import tempfile
 from nipype.algorithms.misc import calc_moments
 
 
-def test_skew():
+def test_skew(tmpdir):
     data = """14.62418305  5.916396751  -1.658088086  4.71113546  1.598428608  5.612553811  -5.004056368  -4.057513911
 11.16365251  17.32688599  -3.099920667  2.630189741  2.389709914  0.379332731  -0.2899694205  -4.363591482
 2.059205599  23.90705054  0.7180462297  -1.976963652  7.487682025  -5.583986129  1.094800525  -2.319858134
@@ -126,13 +125,21 @@ def test_skew():
 -0.5057854071  -2.415896554  -9.663571931  -5.714041661  -6.037933426  8.673756933  10.03557773  8.629816199
 3.622185659  0.4716627142  -10.92515308  -3.705286841  -2.776089545  2.271920902  9.251504922  5.744980887
 """
-    with tempfile.NamedTemporaryFile(delete=True) as f:
-        f.write(data)
-        f.flush()
-        skewness = calc_moments(f.name, 3)
-        yield assert_true, np.allclose(skewness, np.array(
-            [-0.23418937314622, 0.2946365564954823, -0.05781002053540932,
-             -0.3512508282578762, -
-             0.07035664150233077, -
-             0.01935867699166935,
-             0.00483863369427428, 0.21879460029850167]))
+    f = tmpdir.join("filetest")
+    f.write(data)
+    skewness = calc_moments(f.strpath, 3)
+    assert np.allclose(
+        skewness,
+        np.array(
+            [
+                -0.23418937314622,
+                0.2946365564954823,
+                -0.05781002053540932,
+                -0.3512508282578762,
+                -0.07035664150233077,
+                -0.01935867699166935,
+                0.00483863369427428,
+                0.21879460029850167,
+            ]
+        ),
+    )
