@@ -6,8 +6,7 @@ Package contains interfaces for using existing functionality in other packages
 
 Requires Packages to be installed
 """
-from __future__ import print_function, division, unicode_literals, absolute_import
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
-from .io import DataGrabber, DataSink, SelectFiles
+from .io import DataGrabber, DataSink, SelectFiles, BIDSDataGrabber
 from .utility import IdentityInterface, Rename, Function, Select, Merge
