@@ -12,11 +12,6 @@ The I/O specifications corresponding to these base
 interfaces are found in the ``specs`` module.
 
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-
-from builtins import object, open, str, bytes
-
 from copy import deepcopy
 from datetime import datetime as dt
 import os
@@ -26,35 +21,38 @@ import shlex
 import sys
 import simplejson as json
 from dateutil.parser import parse as parseutc
-from future import standard_library
+from traits.trait_errors import TraitError
 
 from ... import config, logging, LooseVersion
 from ...utils.provenance import write_provenance
 from ...utils.misc import str2bool, rgetcwd
-from ...utils.filemanip import (FileNotFoundError, split_filename,
-                                which, get_dependencies)
+from ...utils.filemanip import split_filename, which, get_dependencies, canonicalize_env
 from ...utils.subprocess import run_command
 
 from ...external.due import due
 
-from .traits_extension import traits, isdefined, TraitError
-from .specs import (BaseInterfaceInputSpec, CommandLineInputSpec,
-                    StdOutCommandLineInputSpec, MpiCommandLineInputSpec,
-                    get_filecopy_info)
-from .support import (Bunch, InterfaceResult, NipypeInterfaceError,
-                      format_help)
+from .traits_extension import traits, isdefined, Undefined
+from .specs import (
+    BaseInterfaceInputSpec,
+    CommandLineInputSpec,
+    StdOutCommandLineInputSpec,
+    MpiCommandLineInputSpec,
+    get_filecopy_info,
+)
+from .support import Bunch, InterfaceResult, NipypeInterfaceError, format_help
 
-standard_library.install_aliases()
+iflogger = logging.getLogger("nipype.interface")
 
-iflogger = logging.getLogger('nipype.interface')
-
-PY35 = sys.version_info >= (3, 5)
-PY3 = sys.version_info[0] > 2
 VALID_TERMINAL_OUTPUT = [
-    'stream', 'allatonce', 'file', 'file_split', 'file_stdout', 'file_stderr',
-    'none'
+    "stream",
+    "allatonce",
+    "file",
+    "file_split",
+    "file_stdout",
+    "file_stderr",
+    "none",
 ]
-__docformat__ = 'restructuredtext'
+__docformat__ = "restructuredtext"
 
 
 class Interface(object):
@@ -123,16 +121,14 @@ class Interface(object):
         Necessary for pipeline operation
         """
         iflogger.warning(
-            '_get_filecopy_info member of Interface was deprecated '
-            'in nipype-1.1.6 and will be removed in 1.2.0')
+            "_get_filecopy_info member of Interface was deprecated "
+            "in nipype-1.1.6 and will be removed in 1.2.0"
+        )
         return get_filecopy_info(cls)
 
 
 class BaseInterface(Interface):
-    """Implements common interface functionality.
-
-    Implements
-    ----------
+    """Implement common interface functionality.
 
     * Initializes inputs/outputs from input_spec/output_spec
     * Provides help based on input_spec and output_spec
@@ -145,34 +141,55 @@ class BaseInterface(Interface):
 
     This class cannot be instantiated.
 
-
-    Relevant Interface attributes
-    -----------------------------
-
-    ``input_spec`` points to the traited class for the inputs
-    ``output_spec`` points to the traited class for the outputs
-    ``_redirect_x`` should be set to ``True`` when the interface requires
-      connecting to a ``$DISPLAY`` (default is ``False``).
-    ``resource_monitor`` if ``False`` prevents resource-monitoring this
-      interface, if ``True`` monitoring will be enabled IFF the general
-      Nipype config is set on (``resource_monitor = true``).
-
+    Attributes
+    ----------
+    input_spec: :obj:`nipype.interfaces.base.specs.TraitedSpec`
+        points to the traited class for the inputs
+    output_spec: :obj:`nipype.interfaces.base.specs.TraitedSpec`
+        points to the traited class for the outputs
+    _redirect_x: bool
+        should be set to ``True`` when the interface requires
+        connecting to a ``$DISPLAY`` (default is ``False``).
+    resource_monitor: bool
+        If ``False``, prevents resource-monitoring this interface
+        If ``True`` monitoring will be enabled IFF the general
+        Nipype config is set on (``resource_monitor = true``).
 
     """
+
     input_spec = BaseInterfaceInputSpec
     _version = None
     _additional_metadata = []
     _redirect_x = False
     references_ = []
     resource_monitor = True  # Enabled for this interface IFF enabled in the config
+    _etelemetry_version_data = None
+
+    def __init__(
+        self, from_file=None, resource_monitor=None, ignore_exception=False, **inputs
+    ):
+        if (
+            config.getboolean("execution", "check_version")
+            and "NIPYPE_NO_ET" not in os.environ
+        ):
+            from ... import check_latest_version
+
+            if BaseInterface._etelemetry_version_data is None:
+                BaseInterface._etelemetry_version_data = check_latest_version()
 
-    def __init__(self, from_file=None, resource_monitor=None,
-                 ignore_exception=False, **inputs):
         if not self.input_spec:
-            raise Exception(
-                'No input_spec in class: %s' % self.__class__.__name__)
+            raise Exception("No input_spec in class: %s" % self.__class__.__name__)
+
+        # Create input spec, disable any defaults that are unavailable due to
+        # version, and then apply the inputs that were passed.
+        self.inputs = self.input_spec()
+        unavailable_traits = self._check_version_requirements(
+            self.inputs, permissive=True
+        )
+        if unavailable_traits:
+            self.inputs.trait_set(**{k: Undefined for k in unavailable_traits})
+        self.inputs.trait_set(**inputs)
 
-        self.inputs = self.input_spec(**inputs)
         self.ignore_exception = ignore_exception
 
         if resource_monitor is not None:
@@ -198,34 +215,42 @@ class BaseInterface(Interface):
         """
         if spec.requires:
             values = [
-                not isdefined(getattr(self.inputs, field))
-                for field in spec.requires
+                not isdefined(getattr(self.inputs, field)) for field in spec.requires
             ]
             if any(values) and isdefined(value):
                 if len(values) > 1:
-                    fmt = ("%s requires values for inputs %s because '%s' is set. " 
-                           "For a list of required inputs, see %s.help()")
+                    fmt = (
+                        "%s requires values for inputs %s because '%s' is set. "
+                        "For a list of required inputs, see %s.help()"
+                    )
                 else:
-                    fmt = ("%s requires a value for input %s because '%s' is set. " 
-                           "For a list of required inputs, see %s.help()")
-                msg = fmt % (self.__class__.__name__,
-                             ', '.join("'%s'" % req for req in spec.requires),
-                             name,
-                             self.__class__.__name__)
+                    fmt = (
+                        "%s requires a value for input %s because '%s' is set. "
+                        "For a list of required inputs, see %s.help()"
+                    )
+                msg = fmt % (
+                    self.__class__.__name__,
+                    ", ".join("'%s'" % req for req in spec.requires),
+                    name,
+                    self.__class__.__name__,
+                )
                 raise ValueError(msg)
 
     def _check_xor(self, spec, name, value):
         """ check if mutually exclusive inputs are satisfied
         """
         if spec.xor:
-            values = [
-                isdefined(getattr(self.inputs, field)) for field in spec.xor
-            ]
+            values = [isdefined(getattr(self.inputs, field)) for field in spec.xor]
             if not any(values) and not isdefined(value):
-                msg = ("%s requires a value for one of the inputs '%s'. "
-                       "For a list of required inputs, see %s.help()" %
-                       (self.__class__.__name__, ', '.join(spec.xor),
-                        self.__class__.__name__))
+                msg = (
+                    "%s requires a value for one of the inputs '%s'. "
+                    "For a list of required inputs, see %s.help()"
+                    % (
+                        self.__class__.__name__,
+                        ", ".join(spec.xor),
+                        self.__class__.__name__,
+                    )
+                )
                 raise ValueError(msg)
 
     def _check_mandatory_inputs(self):
@@ -235,19 +260,25 @@ class BaseInterface(Interface):
             value = getattr(self.inputs, name)
             self._check_xor(spec, name, value)
             if not isdefined(value) and spec.xor is None:
-                msg = ("%s requires a value for input '%s'. "
-                       "For a list of required inputs, see %s.help()" %
-                       (self.__class__.__name__, name,
-                        self.__class__.__name__))
+                msg = (
+                    "%s requires a value for input '%s'. "
+                    "For a list of required inputs, see %s.help()"
+                    % (self.__class__.__name__, name, self.__class__.__name__)
+                )
                 raise ValueError(msg)
             if isdefined(value):
                 self._check_requires(spec, name, value)
         for name, spec in list(
-                self.inputs.traits(mandatory=None, transient=None).items()):
+            self.inputs.traits(mandatory=None, transient=None).items()
+        ):
             self._check_requires(spec, name, getattr(self.inputs, name))
 
-    def _check_version_requirements(self, trait_object, raise_exception=True):
+    def _check_version_requirements(self, trait_object, permissive=False):
         """ Raises an exception on version mismatch
+
+        Set the ``permissive`` attribute to True to suppress warnings and exceptions.
+        This is currently only used in __init__ to silently identify unavailable
+        traits.
         """
         unavailable_traits = []
         # check minimum version
@@ -257,16 +288,28 @@ class BaseInterface(Interface):
         if names and self.version:
             version = LooseVersion(str(self.version))
             for name in names:
-                min_ver = LooseVersion(
-                    str(trait_object.traits()[name].min_ver))
-                if min_ver > version:
+                min_ver = LooseVersion(str(trait_object.traits()[name].min_ver))
+                try:
+                    too_old = min_ver > version
+                except TypeError as err:
+                    msg = (
+                        f"Nipype cannot validate the package version {version!r} for "
+                        f"{self.__class__.__name__}. Trait {name} requires version >={min_ver}."
+                    )
+                    if not permissive:
+                        iflogger.warning(f"{msg}. Please verify validity.")
+                    if config.getboolean("execution", "stop_on_unknown_version"):
+                        raise ValueError(msg) from err
+                    continue
+                if too_old:
                     unavailable_traits.append(name)
                     if not isdefined(getattr(trait_object, name)):
                         continue
-                    if raise_exception:
+                    if not permissive:
                         raise Exception(
-                            'Trait %s (%s) (version %s < required %s)' %
-                            (name, self.__class__.__name__, version, min_ver))
+                            "Trait %s (%s) (version %s < required %s)"
+                            % (name, self.__class__.__name__, version, min_ver)
+                        )
 
         # check maximum version
         check = dict(max_ver=lambda t: t is not None)
@@ -274,16 +317,28 @@ class BaseInterface(Interface):
         if names and self.version:
             version = LooseVersion(str(self.version))
             for name in names:
-                max_ver = LooseVersion(
-                    str(trait_object.traits()[name].max_ver))
-                if max_ver < version:
+                max_ver = LooseVersion(str(trait_object.traits()[name].max_ver))
+                try:
+                    too_new = max_ver < version
+                except TypeError as err:
+                    msg = (
+                        f"Nipype cannot validate the package version {version!r} for "
+                        f"{self.__class__.__name__}. Trait {name} requires version <={max_ver}."
+                    )
+                    if not permissive:
+                        iflogger.warning(f"{msg}. Please verify validity.")
+                    if config.getboolean("execution", "stop_on_unknown_version"):
+                        raise ValueError(msg) from err
+                    continue
+                if too_new:
                     unavailable_traits.append(name)
                     if not isdefined(getattr(trait_object, name)):
                         continue
-                    if raise_exception:
+                    if not permissive:
                         raise Exception(
-                            'Trait %s (%s) (version %s > required %s)' %
-                            (name, self.__class__.__name__, version, max_ver))
+                            "Trait %s (%s) (version %s > required %s)"
+                            % (name, self.__class__.__name__, version, max_ver)
+                        )
         return unavailable_traits
 
     def _run_interface(self, runtime):
@@ -295,7 +350,7 @@ class BaseInterface(Interface):
         """ Add the interface references to the duecredit citations
         """
         for r in self.references_:
-            r['path'] = self.__module__
+            r["path"] = self.__module__
             due.cite(**r)
 
     def run(self, cwd=None, ignore_exception=None, **inputs):
@@ -306,14 +361,15 @@ class BaseInterface(Interface):
 
         Parameters
         ----------
-
         cwd : specify a folder where the interface should be run
         inputs : allows the interface settings to be updated
 
         Returns
         -------
-        results :  an InterfaceResult object containing a copy of the instance
-        that was executed, provenance information and, if successful, results
+        results :  :obj:`nipype.interfaces.base.support.InterfaceResult`
+            A copy of the instance that was executed, provenance information and,
+            if successful, results
+
         """
         from ...utils.profiler import ResourceMonitor
 
@@ -337,10 +393,11 @@ class BaseInterface(Interface):
 
         # initialize provenance tracking
         store_provenance = str2bool(
-            config.get('execution', 'write_provenance', 'false'))
+            config.get("execution", "write_provenance", "false")
+        )
         env = deepcopy(dict(os.environ))
         if self._redirect_x:
-            env['DISPLAY'] = config.get_display()
+            env["DISPLAY"] = config.get_display()
 
         runtime = Bunch(
             cwd=cwd,
@@ -352,17 +409,19 @@ class BaseInterface(Interface):
             endTime=None,
             platform=platform.platform(),
             hostname=platform.node(),
-            version=self.version)
+            version=self.version,
+        )
         runtime_attrs = set(runtime.dictcopy())
 
         mon_sp = None
         if enable_rm:
-            mon_freq = float(
-                config.get('execution', 'resource_monitor_frequency', 1))
+            mon_freq = float(config.get("execution", "resource_monitor_frequency", 1))
             proc_pid = os.getpid()
             iflogger.debug(
-                'Creating a ResourceMonitor on a %s interface, PID=%d.',
-                self.__class__.__name__, proc_pid)
+                "Creating a ResourceMonitor on a %s interface, PID=%d.",
+                self.__class__.__name__,
+                proc_pid,
+            )
             mon_sp = ResourceMonitor(proc_pid, freq=mon_freq)
             mon_sp.start()
 
@@ -377,38 +436,37 @@ class BaseInterface(Interface):
             outputs = self.aggregate_outputs(runtime)
         except Exception as e:
             import traceback
+
             # Retrieve the maximum info fast
             runtime.traceback = traceback.format_exc()
             # Gather up the exception arguments and append nipype info.
-            exc_args = e.args if getattr(e, 'args') else tuple()
+            exc_args = e.args if getattr(e, "args") else tuple()
             exc_args += (
-                'An exception of type %s occurred while running interface %s.'
-                % (type(e).__name__, self.__class__.__name__), )
-            if config.get('logging', 'interface_level',
-                          'info').lower() == 'debug':
-                exc_args += ('Inputs: %s' % str(self.inputs), )
+                "An exception of type %s occurred while running interface %s."
+                % (type(e).__name__, self.__class__.__name__),
+            )
+            if config.get("logging", "interface_level", "info").lower() == "debug":
+                exc_args += ("Inputs: %s" % str(self.inputs),)
 
-            runtime.traceback_args = ('\n'.join(
-                ['%s' % arg for arg in exc_args]), )
+            runtime.traceback_args = ("\n".join(["%s" % arg for arg in exc_args]),)
 
             if not ignore_exception:
                 raise
         finally:
             if runtime is None or runtime_attrs - set(runtime.dictcopy()):
-                raise RuntimeError("{} interface failed to return valid "
-                                   "runtime object".format(
-                                       interface.__class__.__name__))
+                raise RuntimeError(
+                    "{} interface failed to return valid "
+                    "runtime object".format(interface.__class__.__name__)
+                )
             # This needs to be done always
             runtime.endTime = dt.isoformat(dt.utcnow())
             timediff = parseutc(runtime.endTime) - parseutc(runtime.startTime)
-            runtime.duration = (timediff.days * 86400 + timediff.seconds +
-                                timediff.microseconds / 1e6)
+            runtime.duration = (
+                timediff.days * 86400 + timediff.seconds + timediff.microseconds / 1e6
+            )
             results = InterfaceResult(
-                interface,
-                runtime,
-                inputs=inputs,
-                outputs=outputs,
-                provenance=None)
+                interface, runtime, inputs=inputs, outputs=outputs, provenance=None
+            )
 
             # Add provenance (if required)
             if store_provenance:
@@ -418,23 +476,24 @@ class BaseInterface(Interface):
             # Make sure runtime profiler is shut down
             if enable_rm:
                 import numpy as np
+
                 mon_sp.stop()
 
                 runtime.mem_peak_gb = None
                 runtime.cpu_percent = None
 
                 # Read .prof file in and set runtime values
-                vals = np.loadtxt(mon_sp.fname, delimiter=',')
+                vals = np.loadtxt(mon_sp.fname, delimiter=",")
                 if vals.size:
                     vals = np.atleast_2d(vals)
                     runtime.mem_peak_gb = vals[:, 2].max() / 1024
                     runtime.cpu_percent = vals[:, 1].max()
 
                     runtime.prof_dict = {
-                        'time': vals[:, 0].tolist(),
-                        'cpus': vals[:, 1].tolist(),
-                        'rss_GiB': (vals[:, 2] / 1024).tolist(),
-                        'vms_GiB': (vals[:, 3] / 1024).tolist(),
+                        "time": vals[:, 0].tolist(),
+                        "cpus": vals[:, 1].tolist(),
+                        "rss_GiB": (vals[:, 2] / 1024).tolist(),
+                        "vms_GiB": (vals[:, 3] / 1024).tolist(),
                     }
             os.chdir(syscwd)
 
@@ -449,42 +508,50 @@ class BaseInterface(Interface):
             return None
 
     def aggregate_outputs(self, runtime=None, needed_outputs=None):
-        """ Collate expected outputs and check for existence
-        """
+        """Collate expected outputs and apply output traits validation."""
+        outputs = self._outputs()  # Generate an empty output spec object
+        predicted_outputs = self._list_outputs()  # Predictions from _list_outputs
+        if not predicted_outputs:
+            return outputs
 
-        predicted_outputs = self._list_outputs()
-        outputs = self._outputs()
-        if predicted_outputs:
-            _unavailable_outputs = []
-            if outputs:
-                _unavailable_outputs = \
-                    self._check_version_requirements(self._outputs())
-            for key, val in list(predicted_outputs.items()):
-                if needed_outputs and key not in needed_outputs:
-                    continue
-                if key in _unavailable_outputs:
-                    raise KeyError(('Output trait %s not available in version '
-                                    '%s of interface %s. Please inform '
-                                    'developers.') % (key, self.version,
-                                                      self.__class__.__name__))
-                try:
-                    setattr(outputs, key, val)
-                except TraitError as error:
-                    if getattr(error, 'info',
-                               'default').startswith('an existing'):
-                        msg = ("File/Directory '%s' not found for %s output "
-                               "'%s'." % (val, self.__class__.__name__, key))
-                        raise FileNotFoundError(msg)
-                    raise error
+        # Precalculate the list of output trait names that should be aggregated
+        aggregate_names = set(predicted_outputs)
+        if needed_outputs is not None:
+            aggregate_names = set(needed_outputs).intersection(aggregate_names)
 
+        if aggregate_names:  # Make sure outputs are compatible
+            _na_outputs = self._check_version_requirements(outputs)
+            na_names = aggregate_names.intersection(_na_outputs)
+            if na_names:
+                # XXX Change to TypeError in Nipype 2.0
+                raise KeyError(
+                    """\
+Output trait(s) %s not available in version %s of interface %s.\
+"""
+                    % (", ".join(na_names), self.version, self.__class__.__name__)
+                )
+
+        for key in aggregate_names:  # Final aggregation
+            val = predicted_outputs[key]
+            try:
+                setattr(outputs, key, val)
+            except TraitError as error:
+                if "an existing" in getattr(error, "info", "default"):
+                    msg = (
+                        "No such file or directory '%s' for output '%s' of a %s interface"
+                        % (val, key, self.__class__.__name__)
+                    )
+                    raise FileNotFoundError(msg)
+                raise error
         return outputs
 
     @property
     def version(self):
         if self._version is None:
-            if str2bool(config.get('execution', 'stop_on_unknown_version')):
-                raise ValueError('Interface %s has no version information' %
-                                 self.__class__.__name__)
+            if str2bool(config.get("execution", "stop_on_unknown_version")):
+                raise ValueError(
+                    "Interface %s has no version information" % self.__class__.__name__
+                )
         return self._version
 
     def load_inputs_from_json(self, json_file, overwrite=True):
@@ -509,8 +576,8 @@ class BaseInterface(Interface):
         A convenient way to save current inputs to a JSON file.
         """
         inputs = self.inputs.get_traitsfree()
-        iflogger.debug('saving inputs %s', inputs)
-        with open(json_file, 'w' if PY3 else 'wb') as fhandle:
+        iflogger.debug("saving inputs %s", inputs)
+        with open(json_file, "w") as fhandle:
             json.dump(inputs, fhandle, indent=4, ensure_ascii=False)
 
     def _pre_run_hook(self, runtime):
@@ -549,7 +616,6 @@ class SimpleInterface(BaseInterface):
 
     Examples
     --------
-
     >>> from nipype.interfaces.base import (
     ...     SimpleInterface, BaseInterfaceInputSpec, TraitedSpec)
 
@@ -574,11 +640,13 @@ class SimpleInterface(BaseInterface):
     >>> dbl.inputs.x = 2
     >>> dbl.run().outputs.doubled
     4.0
+
     """
 
     def __init__(self, from_file=None, resource_monitor=None, **inputs):
         super(SimpleInterface, self).__init__(
-            from_file=from_file, resource_monitor=resource_monitor, **inputs)
+            from_file=from_file, resource_monitor=resource_monitor, **inputs
+        )
         self._results = {}
 
     def _list_outputs(self):
@@ -591,14 +659,11 @@ class CommandLine(BaseInterface):
 
     Parameters
     ----------
-
-    command : string
+    command : str
         define base immutable `command` you wish to run
-
-    args : string, optional
+    args : str, optional
         optional arguments passed to base `command`
 
-
     Examples
     --------
     >>> import pprint
@@ -608,7 +673,7 @@ class CommandLine(BaseInterface):
     >>> cli.cmdline
     'ls -al'
 
-    # Use get_traitsfree() to check all inputs set
+    >>> # Use get_traitsfree() to check all inputs set
     >>> pprint.pprint(cli.inputs.get_traitsfree())  # doctest:
     {'args': '-al',
      'environ': {'DISPLAY': ':1'}}
@@ -619,11 +684,12 @@ class CommandLine(BaseInterface):
     '11c37f97649cd61627f4afe5136af8c0'
 
     """
+
     input_spec = CommandLineInputSpec
-    _cmd_prefix = ''
+    _cmd_prefix = ""
     _cmd = None
     _version = None
-    _terminal_output = 'stream'
+    _terminal_output = "stream"
 
     @classmethod
     def set_default_terminal_output(cls, output_type):
@@ -638,18 +704,16 @@ class CommandLine(BaseInterface):
         if output_type in VALID_TERMINAL_OUTPUT:
             cls._terminal_output = output_type
         else:
-            raise AttributeError(
-                'Invalid terminal output_type: %s' % output_type)
+            raise AttributeError("Invalid terminal output_type: %s" % output_type)
 
     def __init__(self, command=None, terminal_output=None, **inputs):
         super(CommandLine, self).__init__(**inputs)
         self._environ = None
         # Set command. Input argument takes precedence
-        self._cmd = command or getattr(self, '_cmd', None)
+        self._cmd = command or getattr(self, "_cmd", None)
 
         # Store dependencies in runtime object
-        self._ldd = str2bool(
-            config.get('execution', 'get_linked_libs', 'true'))
+        self._ldd = str2bool(config.get("execution", "get_linked_libs", "true"))
 
         if self._cmd is None:
             raise Exception("Missing command")
@@ -662,8 +726,9 @@ class CommandLine(BaseInterface):
         """sets base command, immutable"""
         if not self._cmd:
             raise NotImplementedError(
-                'CommandLineInterface should wrap an executable, but '
-                'none has been set.')
+                "CommandLineInterface should wrap an executable, but "
+                "none has been set."
+            )
         return self._cmd
 
     @property
@@ -672,7 +737,7 @@ class CommandLine(BaseInterface):
         validates arguments and generates command line"""
         self._check_mandatory_inputs()
         allargs = [self._cmd_prefix + self.cmd] + self._parse_inputs()
-        return ' '.join(allargs)
+        return " ".join(allargs)
 
     @property
     def terminal_output(self):
@@ -683,23 +748,26 @@ class CommandLine(BaseInterface):
         if value not in VALID_TERMINAL_OUTPUT:
             raise RuntimeError(
                 'Setting invalid value "%s" for terminal_output. Valid values are '
-                '%s.' % (value,
-                         ', '.join(['"%s"' % v
-                                    for v in VALID_TERMINAL_OUTPUT])))
+                "%s." % (value, ", ".join(['"%s"' % v for v in VALID_TERMINAL_OUTPUT]))
+            )
         self._terminal_output = value
 
     def raise_exception(self, runtime):
         raise RuntimeError(
-            ('Command:\n{cmdline}\nStandard output:\n{stdout}\n'
-             'Standard error:\n{stderr}\nReturn code: {returncode}'
-             ).format(**runtime.dictcopy()))
+            (
+                "Command:\n{cmdline}\nStandard output:\n{stdout}\n"
+                "Standard error:\n{stderr}\nReturn code: {returncode}"
+            ).format(**runtime.dictcopy())
+        )
 
     def _get_environ(self):
-        return getattr(self.inputs, 'environ', {})
+        return getattr(self.inputs, "environ", {})
 
-    def version_from_command(self, flag='-v', cmd=None):
-        iflogger.warning('version_from_command member of CommandLine was '
-                         'Deprecated in nipype-1.0.0 and deleted in 1.1.0')
+    def version_from_command(self, flag="-v", cmd=None):
+        iflogger.warning(
+            "version_from_command member of CommandLine was "
+            "Deprecated in nipype-1.0.0 and deleted in 1.1.0"
+        )
         if cmd is None:
             cmd = self.cmd.split()[0]
 
@@ -708,16 +776,16 @@ class CommandLine(BaseInterface):
             out_environ = self._get_environ()
             env.update(out_environ)
             proc = sp.Popen(
-                ' '.join((cmd, flag)),
+                " ".join((cmd, flag)),
                 shell=True,
-                env=env,
+                env=canonicalize_env(env),
                 stdout=sp.PIPE,
                 stderr=sp.PIPE,
             )
             o, e = proc.communicate()
             return o
 
-    def _run_interface(self, runtime, correct_return_codes=(0, )):
+    def _run_interface(self, runtime, correct_return_codes=(0,)):
         """Execute command via subprocess
 
         Parameters
@@ -726,7 +794,8 @@ class CommandLine(BaseInterface):
 
         Returns
         -------
-        runtime : updated runtime information
+        runtime :
+            updated runtime information
             adds stdout, stderr, merged, cmdline, dependencies, command_path
 
         """
@@ -745,16 +814,18 @@ class CommandLine(BaseInterface):
         if cmd_path is None:
             raise IOError(
                 'No command "%s" found on host %s. Please check that the '
-                'corresponding package is installed.' % (executable_name,
-                                                         runtime.hostname))
+                "corresponding package is installed."
+                % (executable_name, runtime.hostname)
+            )
 
         runtime.command_path = cmd_path
-        runtime.dependencies = (get_dependencies(executable_name,
-                                                 runtime.environ)
-                                if self._ldd else '<skipped>')
+        runtime.dependencies = (
+            get_dependencies(executable_name, runtime.environ)
+            if self._ldd
+            else "<skipped>"
+        )
         runtime = run_command(runtime, output=self.terminal_output)
-        if runtime.returncode is None or \
-                runtime.returncode not in correct_return_codes:
+        if runtime.returncode is None or runtime.returncode not in correct_return_codes:
             self.raise_exception(runtime)
 
         return runtime
@@ -765,15 +836,15 @@ class CommandLine(BaseInterface):
         Formats a trait containing argstr metadata
         """
         argstr = trait_spec.argstr
-        iflogger.debug('%s_%s', name, value)
+        iflogger.debug("%s_%s", name, value)
         if trait_spec.is_trait_type(traits.Bool) and "%" not in argstr:
             # Boolean options have no format string. Just append options if True.
             return argstr if value else None
         # traits.Either turns into traits.TraitCompound and does not have any
         # inner_traits
-        elif trait_spec.is_trait_type(traits.List) \
-            or (trait_spec.is_trait_type(traits.TraitCompound) and
-                isinstance(value, list)):
+        elif trait_spec.is_trait_type(traits.List) or (
+            trait_spec.is_trait_type(traits.TraitCompound) and isinstance(value, list)
+        ):
             # This is a bit simple-minded at present, and should be
             # construed as the default. If more sophisticated behavior
             # is needed, it can be accomplished with metadata (e.g.
@@ -783,13 +854,13 @@ class CommandLine(BaseInterface):
             # Depending on whether we stick with traitlets, and whether or
             # not we beef up traitlets.List, we may want to put some
             # type-checking code here as well
-            sep = trait_spec.sep if trait_spec.sep is not None else ' '
+            sep = trait_spec.sep if trait_spec.sep is not None else " "
 
-            if argstr.endswith('...'):
+            if argstr.endswith("..."):
                 # repeatable option
                 # --id %d... will expand to
                 # --id 1 --id 2 --id 3 etc.,.
-                argstr = argstr.replace('...', '')
+                argstr = argstr.replace("...", "")
                 return sep.join([argstr % elt for elt in value])
             else:
                 return argstr % sep.join(str(elt) for elt in value)
@@ -809,13 +880,16 @@ class CommandLine(BaseInterface):
                 return retval
 
             # Do not generate filename when excluded by other inputs
-            if any(isdefined(getattr(self.inputs, field))
-                   for field in trait_spec.xor or ()):
+            if any(
+                isdefined(getattr(self.inputs, field)) for field in trait_spec.xor or ()
+            ):
                 return retval
 
             # Do not generate filename when required fields are missing
-            if not all(isdefined(getattr(self.inputs, field))
-                       for field in trait_spec.requires or ()):
+            if not all(
+                isdefined(getattr(self.inputs, field))
+                for field in trait_spec.requires or ()
+            ):
                 return retval
 
             if isdefined(retval) and "%s" in retval:
@@ -828,15 +902,14 @@ class CommandLine(BaseInterface):
             ns = trait_spec.name_source
             while isinstance(ns, (list, tuple)):
                 if len(ns) > 1:
-                    iflogger.warning(
-                        'Only one name_source per trait is allowed')
+                    iflogger.warning("Only one name_source per trait is allowed")
                 ns = ns[0]
 
             if not isinstance(ns, (str, bytes)):
                 raise ValueError(
-                    'name_source of \'{}\' trait should be an input trait '
-                    'name, but a type {} object was found'.format(
-                        name, type(ns)))
+                    "name_source of '{}' trait should be an input trait "
+                    "name, but a type {} object was found".format(name, type(ns))
+                )
 
             if isdefined(getattr(self.inputs, ns)):
                 name_source = ns
@@ -851,8 +924,7 @@ class CommandLine(BaseInterface):
                     base = source
             else:
                 if name in chain:
-                    raise NipypeInterfaceError(
-                        'Mutually pointing name_sources')
+                    raise NipypeInterfaceError("Mutually pointing name_sources")
 
                 chain.append(name)
                 base = self._filename_from_source(ns, chain)
@@ -940,7 +1012,7 @@ class StdOutCommandLine(CommandLine):
     input_spec = StdOutCommandLineInputSpec
 
     def _gen_filename(self, name):
-        return self._gen_outfilename() if name == 'out_file' else None
+        return self._gen_outfilename() if name == "out_file" else None
 
     def _gen_outfilename(self):
         raise NotImplementedError
@@ -962,7 +1034,9 @@ class MpiCommandLine(CommandLine):
     >>> mpi_cli.inputs.n_procs = 8
     >>> mpi_cli.cmdline
     'mpiexec -n 8 my_mpi_prog -v'
+
     """
+
     input_spec = MpiCommandLineInputSpec
 
     @property
@@ -970,11 +1044,11 @@ class MpiCommandLine(CommandLine):
         """Adds 'mpiexec' to begining of command"""
         result = []
         if self.inputs.use_mpi:
-            result.append('mpiexec')
+            result.append("mpiexec")
             if self.inputs.n_procs:
-                result.append('-n %d' % self.inputs.n_procs)
+                result.append("-n %d" % self.inputs.n_procs)
         result.append(super(MpiCommandLine, self).cmdline)
-        return ' '.join(result)
+        return " ".join(result)
 
 
 class SEMLikeCommandLine(CommandLine):
@@ -994,10 +1068,8 @@ class SEMLikeCommandLine(CommandLine):
         for name in list(outputs.keys()):
             corresponding_input = getattr(self.inputs, name)
             if isdefined(corresponding_input):
-                if (isinstance(corresponding_input, bool)
-                        and corresponding_input):
-                    outputs[name] = \
-                        os.path.abspath(self._outputs_filenames[name])
+                if isinstance(corresponding_input, bool) and corresponding_input:
+                    outputs[name] = os.path.abspath(self._outputs_filenames[name])
                 else:
                     if isinstance(corresponding_input, list):
                         outputs[name] = [
@@ -1025,18 +1097,23 @@ class LibraryBaseInterface(BaseInterface):
         super(LibraryBaseInterface, self).__init__(*args, **kwargs)
         if check_import:
             import pkgutil
+
             failed_imports = []
             for pkg in (self._pkg,) + tuple(self.imports):
                 if pkgutil.find_loader(pkg) is None:
                     failed_imports.append(pkg)
             if failed_imports:
-                iflogger.warning('Unable to import %s; %s interface may fail to '
-                                 'run', failed_imports, self.__class__.__name__)
+                iflogger.warning(
+                    "Unable to import %s; %s interface may fail to " "run",
+                    failed_imports,
+                    self.__class__.__name__,
+                )
 
     @property
     def version(self):
         if self._version is None:
             import importlib
+
             try:
                 self._version = importlib.import_module(self._pkg).__version__
             except (ImportError, AttributeError):
@@ -1057,14 +1134,15 @@ class PackageInfo(object):
                     clout = CommandLine(
                         command=klass.version_cmd,
                         resource_monitor=False,
-                        terminal_output='allatonce').run()
+                        terminal_output="allatonce",
+                    ).run()
                 except IOError:
                     return None
 
                 raw_info = clout.runtime.stdout
             elif klass.version_file is not None:
                 try:
-                    with open(klass.version_file, 'rt') as fobj:
+                    with open(klass.version_file, "rt") as fobj:
                         raw_info = fobj.read()
                 except OSError:
                     return None
