@@ -3,6 +3,7 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import os
 import simplejson as json
+import logging
 
 import pytest
 from unittest import mock
@@ -236,6 +237,83 @@ def test_input_version_6():
     obj._check_version_requirements(obj.inputs)
 
 
+def test_input_version_missing(caplog):
+    class DerivedInterface(nib.BaseInterface):
+        class input_spec(nib.TraitedSpec):
+            foo = nib.traits.Int(min_ver="0.9")
+            bar = nib.traits.Int(max_ver="0.9")
+
+        _version = "misparsed-garbage"
+
+    obj = DerivedInterface()
+    obj.inputs.foo = 1
+    obj.inputs.bar = 1
+    with caplog.at_level(logging.WARNING, logger="nipype.interface"):
+        obj._check_version_requirements(obj.inputs)
+    assert len(caplog.records) == 2
+
+
+def test_input_version_missing_error(caplog):
+    from nipype import config
+
+    class DerivedInterface(nib.BaseInterface):
+        class input_spec(nib.TraitedSpec):
+            foo = nib.traits.Int(min_ver="0.9")
+            bar = nib.traits.Int(max_ver="0.9")
+
+        _version = "misparsed-garbage"
+
+    obj1 = DerivedInterface(foo=1)
+    obj2 = DerivedInterface(bar=1)
+    with caplog.at_level(logging.WARNING, logger="nipype.interface"):
+        with mock.patch.object(config, "getboolean", return_value=True):
+            with pytest.raises(ValueError):
+                obj1._check_version_requirements(obj1.inputs)
+            with pytest.raises(ValueError):
+                obj2._check_version_requirements(obj2.inputs)
+    assert len(caplog.records) == 2
+
+
+def test_unavailable_input():
+    class WithInput(nib.BaseInterface):
+        class input_spec(nib.TraitedSpec):
+            foo = nib.traits.Int(3, usedefault=True, max_ver="0.5")
+
+        _version = "0.4"
+
+        def _run_interface(self, runtime):
+            return runtime
+
+    class WithoutInput(WithInput):
+        _version = "0.6"
+
+    has = WithInput()
+    hasnt = WithoutInput()
+    trying_anyway = WithoutInput(foo=3)
+    assert has.inputs.foo == 3
+    assert not nib.isdefined(hasnt.inputs.foo)
+    assert trying_anyway.inputs.foo == 3
+
+    has.run()
+    hasnt.run()
+    with pytest.raises(Exception):
+        trying_anyway.run()
+
+    # Still settable
+    has.inputs.foo = 4
+    hasnt.inputs.foo = 4
+    trying_anyway.inputs.foo = 4
+    assert has.inputs.foo == 4
+    assert hasnt.inputs.foo == 4
+    assert trying_anyway.inputs.foo == 4
+
+    has.run()
+    with pytest.raises(Exception):
+        hasnt.run()
+    with pytest.raises(Exception):
+        trying_anyway.run()
+
+
 def test_output_version():
     class InputSpec(nib.TraitedSpec):
         foo = nib.traits.Int(desc="a random int")
@@ -457,7 +535,7 @@ def test_global_CommandLine_output(tmpdir):
     ci = BET()
     assert ci.terminal_output == "stream"  # default case
 
-    with mock.patch.object(nib.CommandLine, '_terminal_output'):
+    with mock.patch.object(nib.CommandLine, "_terminal_output"):
         nib.CommandLine.set_default_terminal_output("allatonce")
         ci = nib.CommandLine(command="ls -l")
         assert ci.terminal_output == "allatonce"
