@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """The dtk module provides basic functions for interfacing with
@@ -12,9 +13,11 @@ Examples
 See the docstrings for the individual classes for 'working' examples.
 
 """
-__docformat__ = 'restructuredtext'
 import re
-from nipype.interfaces.base import CommandLine
+from ..base import CommandLine
+
+__docformat__ = "restructuredtext"
+
 
 class Info(object):
     """ Handle dtk output type and version information.
@@ -42,13 +45,12 @@ class Info(object):
            Version number as string or None if FSL not found
 
         """
-        clout = CommandLine(command='dti_recon',
-                            terminal_output='allatonce').run()
+        clout = CommandLine(command="dti_recon", terminal_output="allatonce").run()
 
         if clout.runtime.returncode is not 0:
             return None
 
         dtirecon = clout.runtime.stdout
-        result = re.search('dti_recon (.*)\n', dtirecon)
+        result = re.search("dti_recon (.*)\n", dtirecon)
         version = result.group(0).split()[1]
         return version
