@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
 
+import numpy as np
 import nibabel as nb
 
 from ... import logging
 from ..base import TraitedSpec, File, isdefined
 from .base import DipyDiffusionInterface, DipyBaseInterfaceInputSpec
 
-IFLOGGER = logging.getLogger('nipype.interface')
+IFLOGGER = logging.getLogger("nipype.interface")
 
 
 class APMQballInputSpec(DipyBaseInterfaceInputSpec):
-    mask_file = File(exists=True, desc='An optional brain mask')
+    mask_file = File(exists=True, desc="An optional brain mask")
 
 
 class APMQballOutputSpec(TraitedSpec):
@@ -33,6 +32,7 @@ class APMQball(DipyDiffusionInterface):
     >>> apm.inputs.in_bval = 'bvals'
     >>> apm.run()                                   # doctest: +SKIP
     """
+
     input_spec = APMQballInputSpec
     output_spec = APMQballOutputSpec
 
@@ -44,31 +44,32 @@ class APMQball(DipyDiffusionInterface):
         gtab = self._get_gradient_table()
 
         img = nb.load(self.inputs.in_file)
-        data = img.get_data()
+        data = np.asanyarray(img.dataobj)
         affine = img.affine
         mask = None
         if isdefined(self.inputs.mask_file):
-            mask = nb.load(self.inputs.mask_file).get_data()
+            mask = np.asanyarray(nb.load(self.inputs.mask_file).dataobj)
 
         # Fit it
         model = shm.QballModel(gtab, 8)
-        sphere = get_sphere('symmetric724')
+        sphere = get_sphere("symmetric724")
         peaks = peaks_from_model(
             model=model,
             data=data,
-            relative_peak_threshold=.5,
+            relative_peak_threshold=0.5,
             min_separation_angle=25,
             sphere=sphere,
-            mask=mask)
+            mask=mask,
+        )
         apm = shm.anisotropic_power(peaks.shm_coeff)
-        out_file = self._gen_filename('apm')
+        out_file = self._gen_filename("apm")
         nb.Nifti1Image(apm.astype("float32"), affine).to_filename(out_file)
-        IFLOGGER.info('APM qball image saved as %s', out_file)
+        IFLOGGER.info("APM qball image saved as %s", out_file)
 
         return runtime
 
     def _list_outputs(self):
         outputs = self._outputs().get()
-        outputs['out_file'] = self._gen_filename('apm')
+        outputs["out_file"] = self._gen_filename("apm")
 
         return outputs
