@@ -25,9 +25,6 @@ Examples
 See the docstrings of the individual classes for examples.
 
 """
-from __future__ import print_function, division, unicode_literals, \
-    absolute_import
-
 import os
 
 from ... import logging
@@ -36,28 +33,28 @@ from ..base import CommandLine
 from nipype.interfaces.fsl.base import Info
 import warnings
 
-LOGGER = logging.getLogger('nipype.interface')
+LOGGER = logging.getLogger("nipype.interface")
 
 
 class DTITKRenameMixin(object):
     def __init__(self, *args, **kwargs):
         classes = [cls.__name__ for cls in self.__class__.mro()]
         dep_name = classes[0]
-        rename_idx = classes.index('DTITKRenameMixin')
+        rename_idx = classes.index("DTITKRenameMixin")
         new_name = classes[rename_idx + 1]
-        warnings.warn('The {} interface has been renamed to {}\n'
-                      'Please see the documentation for DTI-TK '
-                      'interfaces, as some inputs have been '
-                      'added or renamed for clarity.'
-                      ''.format(dep_name, new_name),
-                      DeprecationWarning)
+        warnings.warn(
+            "The {} interface has been renamed to {}\n"
+            "Please see the documentation for DTI-TK "
+            "interfaces, as some inputs have been "
+            "added or renamed for clarity."
+            "".format(dep_name, new_name),
+            DeprecationWarning,
+        )
         super(DTITKRenameMixin, self).__init__(*args, **kwargs)
 
 
 class CommandLineDtitk(CommandLine):
-
-    def _gen_fname(self, basename, cwd=None, suffix=None, change_ext=True,
-                   ext=None):
+    def _gen_fname(self, basename, cwd=None, suffix=None, change_ext=True, ext=None):
         """Generate a filename based on the given parameters.
 
         The filename will take the form: cwd/basename<suffix><ext>.
@@ -83,9 +80,9 @@ class CommandLineDtitk(CommandLine):
 
         """
 
-        if basename == '':
-            msg = 'Unable to generate filename for command %s. ' % self.cmd
-            msg += 'basename is not set!'
+        if basename == "":
+            msg = "Unable to generate filename for command %s. " % self.cmd
+            msg += "basename is not set!"
             raise ValueError(msg)
         if cwd is None:
             cwd = os.getcwd()
@@ -93,11 +90,10 @@ class CommandLineDtitk(CommandLine):
             ext = Info.output_type_to_ext(self.inputs.output_type)
         if change_ext:
             if suffix:
-                suffix = ''.join((suffix, ext))
+                suffix = "".join((suffix, ext))
             else:
                 suffix = ext
         if suffix is None:
-            suffix = ''
-        fname = fname_presuffix(basename, suffix=suffix,
-                                use_ext=False, newpath=cwd)
+            suffix = ""
+        fname = fname_presuffix(basename, suffix=suffix, use_ext=False, newpath=cwd)
         return fname
