@@ -1,81 +1,89 @@
 # -*- coding: utf-8 -*-
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import str, bytes
-
 import os.path as op
 import glob
 
 from ... import logging
 from ...utils.filemanip import simplify_list
-from ..base import (traits, File, Directory, TraitedSpec, OutputMultiPath)
+from ..base import traits, File, Directory, TraitedSpec, OutputMultiPath
 from ..freesurfer.base import FSCommand, FSTraitedSpec
 
-iflogger = logging.getLogger('nipype.interface')
+iflogger = logging.getLogger("nipype.interface")
 
 
 class WatershedBEMInputSpec(FSTraitedSpec):
     subject_id = traits.Str(
-        argstr='--subject %s',
+        argstr="--subject %s",
         mandatory=True,
-        desc='Subject ID (must have a complete Freesurfer directory)')
+        desc="Subject ID (must have a complete Freesurfer directory)",
+    )
     subjects_dir = Directory(
         exists=True,
         mandatory=True,
         usedefault=True,
-        desc='Path to Freesurfer subjects directory')
+        desc="Path to Freesurfer subjects directory",
+    )
     volume = traits.Enum(
-        'T1',
-        'aparc+aseg',
-        'aseg',
-        'brain',
-        'orig',
-        'brainmask',
-        'ribbon',
-        argstr='--volume %s',
+        "T1",
+        "aparc+aseg",
+        "aseg",
+        "brain",
+        "orig",
+        "brainmask",
+        "ribbon",
+        argstr="--volume %s",
         usedefault=True,
-        desc='The volume from the "mri" directory to use (defaults to T1)')
+        desc='The volume from the "mri" directory to use (defaults to T1)',
+    )
     overwrite = traits.Bool(
         True,
         usedefault=True,
-        argstr='--overwrite',
-        desc='Overwrites the existing files')
+        argstr="--overwrite",
+        desc="Overwrites the existing files",
+    )
     atlas_mode = traits.Bool(
-        argstr='--atlas',
-        desc='Use atlas mode for registration (default: no rigid alignment)')
+        argstr="--atlas",
+        desc="Use atlas mode for registration (default: no rigid alignment)",
+    )
 
 
 class WatershedBEMOutputSpec(TraitedSpec):
     mesh_files = OutputMultiPath(
         File(exists=True),
-        desc=('Paths to the output meshes (brain, inner '
-              'skull, outer skull, outer skin)'))
+        desc=(
+            "Paths to the output meshes (brain, inner "
+            "skull, outer skull, outer skin)"
+        ),
+    )
     brain_surface = File(
-        exists=True,
-        loc='bem/watershed',
-        desc='Brain surface (in Freesurfer format)')
+        exists=True, loc="bem/watershed", desc="Brain surface (in Freesurfer format)"
+    )
     inner_skull_surface = File(
         exists=True,
-        loc='bem/watershed',
-        desc='Inner skull surface (in Freesurfer format)')
+        loc="bem/watershed",
+        desc="Inner skull surface (in Freesurfer format)",
+    )
     outer_skull_surface = File(
         exists=True,
-        loc='bem/watershed',
-        desc='Outer skull surface (in Freesurfer format)')
+        loc="bem/watershed",
+        desc="Outer skull surface (in Freesurfer format)",
+    )
     outer_skin_surface = File(
         exists=True,
-        loc='bem/watershed',
-        desc='Outer skin surface (in Freesurfer format)')
+        loc="bem/watershed",
+        desc="Outer skin surface (in Freesurfer format)",
+    )
     fif_file = File(
         exists=True,
-        loc='bem',
-        altkey='fif',
-        desc='"fif" format file for EEG processing in MNE')
+        loc="bem",
+        altkey="fif",
+        desc='"fif" format file for EEG processing in MNE',
+    )
     cor_files = OutputMultiPath(
         File(exists=True),
-        loc='bem/watershed/ws',
-        altkey='COR',
-        desc='"COR" format files')
+        loc="bem/watershed/ws",
+        altkey="COR",
+        desc='"COR" format files',
+    )
 
 
 class WatershedBEM(FSCommand):
@@ -89,23 +97,23 @@ class WatershedBEM(FSCommand):
     >>> bem.inputs.subject_id = 'subj1'
     >>> bem.inputs.subjects_dir = '.'
     >>> bem.cmdline
-    'mne_watershed_bem --overwrite --subject subj1 --volume T1'
+    'mne watershed_bem --overwrite --subject subj1 --volume T1'
     >>> bem.run() 				# doctest: +SKIP
 
    """
 
-    _cmd = 'mne_watershed_bem'
+    _cmd = "mne watershed_bem"
     input_spec = WatershedBEMInputSpec
     output_spec = WatershedBEMOutputSpec
-    _additional_metadata = ['loc', 'altkey']
+    _additional_metadata = ["loc", "altkey"]
 
     def _get_files(self, path, key, dirval, altkey=None):
-        globsuffix = '*'
-        globprefix = '*'
+        globsuffix = "*"
+        globprefix = "*"
         keydir = op.join(path, dirval)
         if altkey:
             key = altkey
-        globpattern = op.join(keydir, ''.join((globprefix, key, globsuffix)))
+        globpattern = op.join(keydir, "".join((globprefix, key, globsuffix)))
         return glob.glob(globpattern)
 
     def _list_outputs(self):
@@ -115,10 +123,13 @@ class WatershedBEM(FSCommand):
         output_traits = self._outputs()
         mesh_paths = []
         for k in list(outputs.keys()):
-            if k != 'mesh_files':
-                val = self._get_files(subject_path, k,
-                                      output_traits.traits()[k].loc,
-                                      output_traits.traits()[k].altkey)
+            if k != "mesh_files":
+                val = self._get_files(
+                    subject_path,
+                    k,
+                    output_traits.traits()[k].loc,
+                    output_traits.traits()[k].altkey,
+                )
                 if val:
                     value_list = simplify_list(val)
                     if isinstance(value_list, list):
@@ -130,7 +141,7 @@ class WatershedBEM(FSCommand):
                     else:
                         raise TypeError
                     outputs[k] = out_files
-                    if not k.rfind('surface') == -1:
+                    if not k.rfind("surface") == -1:
                         mesh_paths.append(out_files)
-        outputs['mesh_files'] = mesh_paths
+        outputs["mesh_files"] = mesh_paths
         return outputs
