@@ -1,15 +1,7 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-"""Defines functionality for pipelined execution of interfaces
-
-The `EngineBase` class implements the more general view of a task.
-"""
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import object
-
+"""Defines functionality for pipelined execution of interfaces."""
 from copy import deepcopy
 import re
 import numpy as np
@@ -20,10 +12,15 @@ from ...utils.filemanip import loadpkl, savepkl
 
 
 class EngineBase(object):
-    """Defines common attributes and functions for workflows and nodes."""
+    """
+    Defines common attributes and functions for workflows and nodes.
+
+    Implements the more general view of a task.
+    """
 
     def __init__(self, name=None, base_dir=None):
-        """ Initialize base parameters of a workflow or node
+        """
+        Initialize base parameters of a workflow or node.
 
         Parameters
         ----------
@@ -35,27 +32,32 @@ class EngineBase(object):
             default=None, which results in the use of mkdtemp
 
         """
+        self._name = None
         self._hierarchy = None
         self.name = name
-        self._id = self.name # for compatibility with node expansion using iterables
+        self._id = self.name  # for compatibility with node expansion using iterables
 
         self.base_dir = base_dir
+        """Define the work directory for this instance of workflow element."""
+
         self.config = deepcopy(config._sections)
 
     @property
     def name(self):
+        """Set the unique name of this workflow element."""
         return self._name
 
     @name.setter
     def name(self, name):
-        if not name or not re.match(r'^[\w-]+$', name):
+        if not name or not re.match(r"^[\w-]+$", name):
             raise ValueError('[Workflow|Node] name "%s" is not valid.' % name)
         self._name = name
 
     @property
     def fullname(self):
+        """Build the full name down the hierarchy."""
         if self._hierarchy:
-            return '%s.%s' % (self._hierarchy, self.name)
+            return "%s.%s" % (self._hierarchy, self.name)
         return self.name
 
     @property
@@ -68,27 +70,28 @@ class EngineBase(object):
 
     @property
     def itername(self):
-        """Name for expanded iterable"""
+        """Get the name of the expanded iterable."""
         itername = self._id
         if self._hierarchy:
-            itername = '%s.%s' % (self._hierarchy, self._id)
+            itername = "%s.%s" % (self._hierarchy, self._id)
         return itername
 
     def clone(self, name):
-        """Clone an EngineBase object
+        """
+        Clone an EngineBase object.
 
         Parameters
         ----------
 
         name : string (mandatory)
             A clone of node or workflow must have a new name
+
         """
         if name == self.name:
-            raise ValueError('Cloning requires a new name, "%s" is '
-                             'in use.' % name)
+            raise ValueError('Cloning requires a new name, "%s" is ' "in use." % name)
         clone = deepcopy(self)
         clone.name = name
-        if hasattr(clone, '_id'):
+        if hasattr(clone, "_id"):
             clone._id = name
         return clone
 
@@ -101,15 +104,20 @@ class EngineBase(object):
         return hasattr(self.inputs, parameter)
 
     def __str__(self):
+        """Convert to string."""
         return self.fullname
 
     def __repr__(self):
+        """Get Python representation."""
         return self.itername
 
     def save(self, filename=None):
+        """Store this workflow element to a file."""
         if filename is None:
-            filename = 'temp.pklz'
+            filename = "temp.pklz"
         savepkl(filename, self)
 
-    def load(self, filename):
+    @staticmethod
+    def load(filename):
+        """Load this workflow element from a file."""
         return loadpkl(filename)
