@@ -1,11 +1,6 @@
 # -*- coding: utf-8 -*-
 """Parallel workflow execution via SGE
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-
-from builtins import object
-
 import os
 import pwd
 import re
@@ -19,7 +14,8 @@ import random
 from ... import logging
 from ...interfaces.base import CommandLine
 from .base import SGELikeBatchManagerBase, logger
-iflogger = logging.getLogger('nipype.interface')
+
+iflogger = logging.getLogger("nipype.interface")
 DEBUGGING_PREFIX = str(int(random.uniform(100, 999)))
 
 
@@ -36,28 +32,39 @@ class QJobInfo(object):
     :author Hans J. Johnson
     """
 
-    def __init__(self, job_num, job_queue_state, job_time, job_queue_name,
-                 job_slots, qsub_command_line):
+    def __init__(
+        self,
+        job_num,
+        job_queue_state,
+        job_time,
+        job_queue_name,
+        job_slots,
+        qsub_command_line,
+    ):
         # self._jobName = None           # Ascii text name of job not unique
         self._job_num = int(
             job_num
         )  # The primary unique identifier for this job, must be an integer!
         # self._jobOwn  = None           # Who owns this job
-        self._job_queue_state = str(
-            job_queue_state)  # ["running","zombie",...??]
+        self._job_queue_state = str(job_queue_state)  # ["running","zombie",...??]
         # self._jobActionState = str(jobActionState)  # ['r','qw','S',...??]
         self._job_time = job_time  # The job start time
-        self._job_info_creation_time = time.time(
+        self._job_info_creation_time = (
+            time.time()
         )  # When this job was created (for comparing against initalization)
         self._job_queue_name = job_queue_name  # Where the job is running
         self._job_slots = int(job_slots)  # How many slots are being used
         self._qsub_command_line = qsub_command_line
 
     def __repr__(self):
-        return '{:<8d}{:12}{:<3d}{:20}{:8}{}'.format(
-            self._job_num, self._job_queue_state, self._job_slots,
+        return "{:<8d}{:12}{:<3d}{:20}{:8}{}".format(
+            self._job_num,
+            self._job_queue_state,
+            self._job_slots,
             time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime(self._job_time)),
-            self._job_queue_name, self._qsub_command_line)
+            self._job_queue_name,
+            self._qsub_command_line,
+        )
 
     def is_initializing(self):
         return self._job_queue_state == "initializing"
@@ -74,26 +81,29 @@ class QJobInfo(object):
     def is_job_state_pending(self):
         """ Return True, unless job is in the "zombie" status
         """
-        time_diff = (time.time() - self._job_info_creation_time)
+        time_diff = time.time() - self._job_info_creation_time
         if self.is_zombie():
             sge_debug_print(
-                "DONE! QJobInfo.IsPending found in 'zombie' list, returning False so claiming done!\n{0}".
-                format(self))
+                "DONE! QJobInfo.IsPending found in 'zombie' list, returning False so claiming done!\n{0}".format(
+                    self
+                )
+            )
             is_pending_status = False  # Job explicitly found as being completed!
         elif self.is_initializing() and (time_diff > 600):
             # if initializing for more than 5 minute, failure due to
             # initialization and completion before registration
             sge_debug_print(
                 "FAILURE! QJobInfo.IsPending found long running at {1} seconds"
-                "'initializing' returning False for to break loop!\n{0}".
-                format(self, time_diff))
+                "'initializing' returning False for to break loop!\n{0}".format(
+                    self, time_diff
+                )
+            )
             is_pending_status = True  # Job initialization took too long, so report!
         else:  # self.is_running() || self.is_pending():
             is_pending_status = True  # Job cache last listed as running
         return is_pending_status  # The job is in one of the hold states
 
-    def update_info(self, job_queue_state, job_time, job_queue_name,
-                    job_slots):
+    def update_info(self, job_queue_state, job_time, job_queue_name, job_slots):
         self._job_queue_state = job_queue_state
         self._job_time = job_time
         self._job_queue_name = job_queue_name
@@ -107,9 +117,9 @@ class QstatSubstitute(object):
     """A wrapper for Qstat to avoid overloading the
     SGE/OGS server with rapid continuous qstat requests"""
 
-    def __init__(self,
-                 qstat_instant_executable='qstat',
-                 qstat_cached_executable='qstat'):
+    def __init__(
+        self, qstat_instant_executable="qstat", qstat_cached_executable="qstat"
+    ):
         """
         :param qstat_instant_executable:
         :param qstat_cached_executable:
@@ -117,7 +127,8 @@ class QstatSubstitute(object):
         self._qstat_instant_executable = qstat_instant_executable
         self._qstat_cached_executable = qstat_cached_executable
         self._out_of_scope_jobs = list()  # Initialize first
-        self._task_dictionary = dict(
+        self._task_dictionary = (
+            dict()
         )  # {'taskid': QJobInfo(), .... }  The dictionaryObject
         self._remove_old_jobs()
 
@@ -137,20 +148,22 @@ class QstatSubstitute(object):
         :return: NONE
         """
         taskid = int(taskid)  # Ensure that it is an integer
-        self._task_dictionary[taskid] = QJobInfo(taskid, "initializing",
-                                                 time.time(), "noQueue", 1,
-                                                 qsub_command_line)
+        self._task_dictionary[taskid] = QJobInfo(
+            taskid, "initializing", time.time(), "noQueue", 1, qsub_command_line
+        )
 
     @staticmethod
     def _qacct_verified_complete(taskid):
         """ request definitive job completion information for the current job
             from the qacct report
         """
-        sge_debug_print("WARNING:  "
-                        "CONTACTING qacct for finished jobs, "
-                        "{0}: {1}".format(time.time(), "Verifying Completion"))
+        sge_debug_print(
+            "WARNING:  "
+            "CONTACTING qacct for finished jobs, "
+            "{0}: {1}".format(time.time(), "Verifying Completion")
+        )
 
-        this_command = 'qacct'
+        this_command = "qacct"
         qacct_retries = 10
         is_complete = False
         while qacct_retries > 0:
@@ -158,17 +171,19 @@ class QstatSubstitute(object):
             try:
                 proc = subprocess.Popen(
                     [
-                        this_command, '-o',
-                        pwd.getpwuid(os.getuid())[0], '-j',
-                        str(taskid)
+                        this_command,
+                        "-o",
+                        pwd.getpwuid(os.getuid())[0],
+                        "-j",
+                        str(taskid),
                     ],
                     stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
+                    stderr=subprocess.PIPE,
+                )
                 qacct_result, _ = proc.communicate()
                 if qacct_result.find(str(taskid)):
                     is_complete = True
-                sge_debug_print(
-                    "NOTE: qacct for jobs\n{0}".format(qacct_result))
+                sge_debug_print("NOTE: qacct for jobs\n{0}".format(qacct_result))
                 break
             except:
                 sge_debug_print("NOTE: qacct call failed")
@@ -183,26 +198,36 @@ class QstatSubstitute(object):
             # jobown =
             # current_job_element.getElementsByTagName('JB_owner')[0].childNodes[0].data
             try:
-                job_queue_name = current_job_element.getElementsByTagName(
-                    'queue_name')[0].childNodes[0].data
+                job_queue_name = (
+                    current_job_element.getElementsByTagName("queue_name")[0]
+                    .childNodes[0]
+                    .data
+                )
             except:
                 job_queue_name = "unknown"
             try:
                 job_slots = int(
-                    current_job_element.getElementsByTagName('slots')[0]
-                    .childNodes[0].data)
+                    current_job_element.getElementsByTagName("slots")[0]
+                    .childNodes[0]
+                    .data
+                )
             except:
                 job_slots = -1
-            job_queue_state = current_job_element.getAttribute('state')
+            job_queue_state = current_job_element.getAttribute("state")
             job_num = int(
-                current_job_element.getElementsByTagName('JB_job_number')[0]
-                .childNodes[0].data)
+                current_job_element.getElementsByTagName("JB_job_number")[0]
+                .childNodes[0]
+                .data
+            )
             try:
-                job_time_text = current_job_element.getElementsByTagName(
-                    'JAT_start_time')[0].childNodes[0].data
+                job_time_text = (
+                    current_job_element.getElementsByTagName("JAT_start_time")[0]
+                    .childNodes[0]
+                    .data
+                )
                 job_time = float(
-                    time.mktime(
-                        time.strptime(job_time_text, "%Y-%m-%dT%H:%M:%S")))
+                    time.mktime(time.strptime(job_time_text, "%Y-%m-%dT%H:%M:%S"))
+                )
             except:
                 job_time = float(0.0)
                 # Make job entry
@@ -210,9 +235,11 @@ class QstatSubstitute(object):
             task_id = int(job_num)
             if task_id in self._task_dictionary:
                 self._task_dictionary[task_id].update_info(
-                    job_queue_state, job_time, job_queue_name, job_slots)
-                sge_debug_print("Updating job:  {0}".format(
-                    self._task_dictionary[task_id]))
+                    job_queue_state, job_time, job_queue_name, job_slots
+                )
+                sge_debug_print(
+                    "Updating job:  {0}".format(self._task_dictionary[task_id])
+                )
                 current_jobs_parsed.append(task_id)
                 # Changed from job_num as "in" is used to check which does not cast
             else:
@@ -232,10 +259,12 @@ class QstatSubstitute(object):
                 if is_completed:
                     self._task_dictionary[dictionary_job].set_state("zombie")
                 else:
-                    sge_debug_print("ERROR:  Job not in current parselist, "
-                                    "and not in done list {0}: {1}".format(
-                                        dictionary_job,
-                                        self._task_dictionary[dictionary_job]))
+                    sge_debug_print(
+                        "ERROR:  Job not in current parselist, "
+                        "and not in done list {0}: {1}".format(
+                            dictionary_job, self._task_dictionary[dictionary_job]
+                        )
+                    )
                     pass
             if self._task_dictionary[dictionary_job].is_initializing():
                 is_completed = self._qacct_verified_complete(dictionary_job)
@@ -245,8 +274,9 @@ class QstatSubstitute(object):
                     sge_debug_print(
                         "ERROR:  Job not in still in intializing mode, "
                         "and not in done list {0}: {1}".format(
-                            dictionary_job,
-                            self._task_dictionary[dictionary_job]))
+                            dictionary_job, self._task_dictionary[dictionary_job]
+                        )
+                    )
                     pass
 
     def _run_qstat(self, reason_for_qstat, force_instant=True):
@@ -257,8 +287,10 @@ class QstatSubstitute(object):
             -s z gives recently completed jobs (**recently** is very ambiguous)
             -s s suspended jobs
         """
-        sge_debug_print("WARNING:  CONTACTING qmaster for jobs, "
-                        "{0}: {1}".format(time.time(), reason_for_qstat))
+        sge_debug_print(
+            "WARNING:  CONTACTING qmaster for jobs, "
+            "{0}: {1}".format(time.time(), reason_for_qstat)
+        )
         if force_instant:
             this_command = self._qstat_instant_executable
         else:
@@ -270,22 +302,27 @@ class QstatSubstitute(object):
             try:
                 proc = subprocess.Popen(
                     [
-                        this_command, '-u',
-                        pwd.getpwuid(os.getuid())[0], '-xml', '-s', 'psrz'
+                        this_command,
+                        "-u",
+                        pwd.getpwuid(os.getuid())[0],
+                        "-xml",
+                        "-s",
+                        "psrz",
                     ],
                     stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE)
+                    stderr=subprocess.PIPE,
+                )
                 qstat_xml_result, _ = proc.communicate()
                 dom = xml.dom.minidom.parseString(qstat_xml_result)
-                jobs = dom.getElementsByTagName('job_info')
+                jobs = dom.getElementsByTagName("job_info")
                 run = jobs[0]
-                runjobs = run.getElementsByTagName('job_list')
+                runjobs = run.getElementsByTagName("job_list")
                 self._parse_qstat_job_list(runjobs)
                 break
             except Exception as inst:
                 exception_message = "QstatParsingError:\n\t{0}\n\t{1}\n".format(
                     type(inst),  # the exception instance
-                    inst  # __str__ allows args to printed directly
+                    inst,  # __str__ allows args to printed directly
                 )
                 sge_debug_print(exception_message)
                 time.sleep(5)
@@ -301,36 +338,37 @@ class QstatSubstitute(object):
         # Check if the task is in the dictionary first (before running qstat)
         if task_id in self._task_dictionary:
             # Trust the cache, only False if state='zombie'
-            job_is_pending = self._task_dictionary[
-                task_id].is_job_state_pending()
+            job_is_pending = self._task_dictionary[task_id].is_job_state_pending()
             # Double check pending jobs in case of change (since we don't check at the beginning)
             if job_is_pending:
                 self._run_qstat(
-                    "checking job pending status {0}".format(task_id), False)
-                job_is_pending = self._task_dictionary[
-                    task_id].is_job_state_pending()
+                    "checking job pending status {0}".format(task_id), False
+                )
+                job_is_pending = self._task_dictionary[task_id].is_job_state_pending()
         else:
-            self._run_qstat("checking job pending status {0}".format(task_id),
-                            True)
+            self._run_qstat("checking job pending status {0}".format(task_id), True)
             if task_id in self._task_dictionary:
                 # Trust the cache, only False if state='zombie'
-                job_is_pending = self._task_dictionary[
-                    task_id].is_job_state_pending()
+                job_is_pending = self._task_dictionary[task_id].is_job_state_pending()
             else:
-                sge_debug_print("ERROR: Job {0} not in task list, "
-                                "even after forced qstat!".format(task_id))
+                sge_debug_print(
+                    "ERROR: Job {0} not in task list, "
+                    "even after forced qstat!".format(task_id)
+                )
                 job_is_pending = False
         if not job_is_pending:
-            sge_debug_print(
-                "DONE! Returning for {0} claiming done!".format(task_id))
+            sge_debug_print("DONE! Returning for {0} claiming done!".format(task_id))
             if task_id in self._task_dictionary:
                 sge_debug_print(
-                    "NOTE: Adding {0} to OutOfScopeJobs list!".format(task_id))
+                    "NOTE: Adding {0} to OutOfScopeJobs list!".format(task_id)
+                )
                 self._out_of_scope_jobs.append(int(task_id))
                 self._task_dictionary.pop(task_id)
             else:
-                sge_debug_print("ERROR: Job {0} not in task list, "
-                                "but attempted to be removed!".format(task_id))
+                sge_debug_print(
+                    "ERROR: Job {0} not in task list, "
+                    "but attempted to be removed!".format(task_id)
+                )
         return job_is_pending
 
 
@@ -347,7 +385,7 @@ def qsub_sanitize_job_name(testjobname):
     if testjobname[0].isalpha():
         return testjobname
     else:
-        return 'J' + testjobname
+        return "J" + testjobname
 
 
 class SGEPlugin(SGELikeBatchManagerBase):
@@ -369,18 +407,18 @@ class SGEPlugin(SGELikeBatchManagerBase):
         """
         self._retry_timeout = 2
         self._max_tries = 2
-        instant_qstat = 'qstat'
-        cached_qstat = 'qstat'
+        instant_qstat = "qstat"
+        cached_qstat = "qstat"
 
-        if 'plugin_args' in kwargs and kwargs['plugin_args']:
-            if 'retry_timeout' in kwargs['plugin_args']:
-                self._retry_timeout = kwargs['plugin_args']['retry_timeout']
-            if 'max_tries' in kwargs['plugin_args']:
-                self._max_tries = kwargs['plugin_args']['max_tries']
-            if 'qstatProgramPath' in kwargs['plugin_args']:
-                instant_qstat = kwargs['plugin_args']['qstatProgramPath']
-            if 'qstatCachedProgramPath' in kwargs['plugin_args']:
-                cached_qstat = kwargs['plugin_args']['qstatCachedProgramPath']
+        if "plugin_args" in kwargs and kwargs["plugin_args"]:
+            if "retry_timeout" in kwargs["plugin_args"]:
+                self._retry_timeout = kwargs["plugin_args"]["retry_timeout"]
+            if "max_tries" in kwargs["plugin_args"]:
+                self._max_tries = kwargs["plugin_args"]["max_tries"]
+            if "qstatProgramPath" in kwargs["plugin_args"]:
+                instant_qstat = kwargs["plugin_args"]["qstatProgramPath"]
+            if "qstatCachedProgramPath" in kwargs["plugin_args"]:
+                cached_qstat = kwargs["plugin_args"]["qstatCachedProgramPath"]
         self._refQstatSubstitute = QstatSubstitute(instant_qstat, cached_qstat)
 
         super(SGEPlugin, self).__init__(template, **kwargs)
@@ -390,36 +428,35 @@ class SGEPlugin(SGELikeBatchManagerBase):
 
     def _submit_batchtask(self, scriptfile, node):
         cmd = CommandLine(
-            'qsub',
+            "qsub",
             environ=dict(os.environ),
             resource_monitor=False,
-            terminal_output='allatonce')
+            terminal_output="allatonce",
+        )
         path = os.path.dirname(scriptfile)
-        qsubargs = ''
+        qsubargs = ""
         if self._qsub_args:
             qsubargs = self._qsub_args
-        if 'qsub_args' in node.plugin_args:
-            if 'overwrite' in node.plugin_args and \
-                    node.plugin_args['overwrite']:
-                qsubargs = node.plugin_args['qsub_args']
+        if "qsub_args" in node.plugin_args:
+            if "overwrite" in node.plugin_args and node.plugin_args["overwrite"]:
+                qsubargs = node.plugin_args["qsub_args"]
             else:
-                qsubargs += (" " + node.plugin_args['qsub_args'])
-        if '-o' not in qsubargs:
-            qsubargs = '%s -o %s' % (qsubargs, path)
-        if '-e' not in qsubargs:
-            qsubargs = '%s -e %s' % (qsubargs, path)
+                qsubargs += " " + node.plugin_args["qsub_args"]
+        if "-o" not in qsubargs:
+            qsubargs = "%s -o %s" % (qsubargs, path)
+        if "-e" not in qsubargs:
+            qsubargs = "%s -e %s" % (qsubargs, path)
         if node._hierarchy:
-            jobname = '.'.join((dict(os.environ)['LOGNAME'], node._hierarchy,
-                                node._id))
+            jobname = ".".join((dict(os.environ)["LOGNAME"], node._hierarchy, node._id))
         else:
-            jobname = '.'.join((dict(os.environ)['LOGNAME'], node._id))
-        jobnameitems = jobname.split('.')
+            jobname = ".".join((dict(os.environ)["LOGNAME"], node._id))
+        jobnameitems = jobname.split(".")
         jobnameitems.reverse()
-        jobname = '.'.join(jobnameitems)
+        jobname = ".".join(jobnameitems)
         jobname = qsub_sanitize_job_name(jobname)
-        cmd.inputs.args = '%s -N %s %s' % (qsubargs, jobname, scriptfile)
+        cmd.inputs.args = "%s -N %s %s" % (qsubargs, jobname, scriptfile)
         oldlevel = iflogger.level
-        iflogger.setLevel(logging.getLevelName('CRITICAL'))
+        iflogger.setLevel(logging.getLevelName("CRITICAL"))
         tries = 0
         result = list()
         while True:
@@ -428,23 +465,29 @@ class SGEPlugin(SGELikeBatchManagerBase):
             except Exception as e:
                 if tries < self._max_tries:
                     tries += 1
-                    time.sleep(
-                        self._retry_timeout)  # sleep 2 seconds and try again.
+                    time.sleep(self._retry_timeout)  # sleep 2 seconds and try again.
                 else:
                     iflogger.setLevel(oldlevel)
-                    raise RuntimeError('\n'.join((('Could not submit sge task'
-                                                   ' for node %s') % node._id,
-                                                  str(e))))
+                    raise RuntimeError(
+                        "\n".join(
+                            (
+                                ("Could not submit sge task" " for node %s") % node._id,
+                                str(e),
+                            )
+                        )
+                    )
             else:
                 break
         iflogger.setLevel(oldlevel)
         # retrieve sge taskid
-        lines = [line for line in result.runtime.stdout.split('\n') if line]
+        lines = [line for line in result.runtime.stdout.split("\n") if line]
         taskid = int(
-            re.match("Your job ([0-9]*) .* has been submitted",
-                     lines[-1]).groups()[0])
+            re.match("Your job ([0-9]*) .* has been submitted", lines[-1]).groups()[0]
+        )
         self._pending[taskid] = node.output_dir()
         self._refQstatSubstitute.add_startup_job(taskid, cmd.cmdline)
-        logger.debug('submitted sge task: %d for node %s with %s' %
-                     (taskid, node._id, cmd.cmdline))
+        logger.debug(
+            "submitted sge task: %d for node %s with %s"
+            % (taskid, node._id, cmd.cmdline)
+        )
         return taskid
