@@ -3,10 +3,6 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Common graph operations for execution
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-from builtins import open
-
 import os
 import getpass
 from socket import gethostname
@@ -16,9 +12,9 @@ from time import strftime
 from traceback import format_exception
 
 from ... import logging
-from ...utils.filemanip import savepkl, crash2txt, makedirs
+from ...utils.filemanip import savepkl, crash2txt
 
-logger = logging.getLogger('nipype.workflow')
+logger = logging.getLogger("nipype.workflow")
 
 
 def report_crash(node, traceback=None, hostname=None):
@@ -26,40 +22,57 @@ def report_crash(node, traceback=None, hostname=None):
     """
     name = node._id
     host = None
-    if node.result and getattr(node.result, 'runtime'):
-        if isinstance(node.result.runtime, list):
-            host = node.result.runtime[0].hostname
-        else:
-            host = node.result.runtime.hostname
+    traceback = traceback or format_exception(*sys.exc_info())
+
+    try:
+        result = node.result
+    except FileNotFoundError:
+        traceback += """
+
+When creating this crashfile, the results file corresponding
+to the node could not be found.""".splitlines(
+            keepends=True
+        )
+    except Exception as exc:
+        traceback += """
+
+During the creation of this crashfile triggered by the above exception,
+another exception occurred:\n\n{}.""".format(
+            exc
+        ).splitlines(
+            keepends=True
+        )
+    else:
+        if getattr(result, "runtime", None):
+            if isinstance(result.runtime, list):
+                host = result.runtime[0].hostname
+            else:
+                host = result.runtime.hostname
 
     # Try everything to fill in the host
     host = host or hostname or gethostname()
-    logger.error('Node %s failed to run on host %s.', name, host)
-    if not traceback:
-        traceback = format_exception(*sys.exc_info())
-    timeofcrash = strftime('%Y%m%d-%H%M%S')
+    logger.error("Node %s failed to run on host %s.", name, host)
+    timeofcrash = strftime("%Y%m%d-%H%M%S")
     try:
         login_name = getpass.getuser()
     except KeyError:
-        login_name = 'UID{:d}'.format(os.getuid())
-    crashfile = 'crash-%s-%s-%s-%s' % (timeofcrash, login_name, name,
-                                       str(uuid.uuid4()))
-    crashdir = node.config['execution'].get('crashdump_dir', os.getcwd())
+        login_name = "UID{:d}".format(os.getuid())
+    crashfile = "crash-%s-%s-%s-%s" % (timeofcrash, login_name, name, str(uuid.uuid4()))
+    crashdir = node.config["execution"].get("crashdump_dir", os.getcwd())
 
-    makedirs(crashdir, exist_ok=True)
+    os.makedirs(crashdir, exist_ok=True)
     crashfile = os.path.join(crashdir, crashfile)
 
-    if node.config['execution']['crashfile_format'].lower() in ['text', 'txt']:
-        crashfile += '.txt'
+    if node.config["execution"]["crashfile_format"].lower() in ("text", "txt", ".txt"):
+        crashfile += ".txt"
     else:
-        crashfile += '.pklz'
+        crashfile += ".pklz"
 
-    logger.error('Saving crash info to %s\n%s', crashfile, ''.join(traceback))
-    if crashfile.endswith('.txt'):
+    logger.error("Saving crash info to %s\n%s", crashfile, "".join(traceback))
+    if crashfile.endswith(".txt"):
         crash2txt(crashfile, dict(node=node, traceback=traceback))
     else:
-        savepkl(crashfile, dict(node=node, traceback=traceback),
-                versioning=True)
+        savepkl(crashfile, dict(node=node, traceback=traceback), versioning=True)
     return crashfile
 
 
@@ -72,30 +85,32 @@ def report_nodes_not_run(notrun):
     if notrun:
         logger.info("***********************************")
         for info in notrun:
-            logger.error("could not run node: %s" % '.'.join(
-                (info['node']._hierarchy, info['node']._id)))
-            logger.info("crashfile: %s" % info['crashfile'])
+            logger.error(
+                "could not run node: %s"
+                % ".".join((info["node"]._hierarchy, info["node"]._id))
+            )
+            logger.info("crashfile: %s" % info["crashfile"])
             logger.debug("The following dependent nodes were not run")
-            for subnode in info['dependents']:
+            for subnode in info["dependents"]:
                 logger.debug(subnode._id)
         logger.info("***********************************")
-        raise RuntimeError(('Workflow did not execute cleanly. '
-                            'Check log for details'))
+        raise RuntimeError(
+            ("Workflow did not execute cleanly. " "Check log for details")
+        )
 
 
 def create_pyscript(node, updatehash=False, store_exception=True):
     # pickle node
-    timestamp = strftime('%Y%m%d_%H%M%S')
+    timestamp = strftime("%Y%m%d_%H%M%S")
     if node._hierarchy:
-        suffix = '%s_%s_%s' % (timestamp, node._hierarchy, node._id)
-        batch_dir = os.path.join(node.base_dir,
-                                 node._hierarchy.split('.')[0], 'batch')
+        suffix = "%s_%s_%s" % (timestamp, node._hierarchy, node._id)
+        batch_dir = os.path.join(node.base_dir, node._hierarchy.split(".")[0], "batch")
     else:
-        suffix = '%s_%s' % (timestamp, node._id)
-        batch_dir = os.path.join(node.base_dir, 'batch')
+        suffix = "%s_%s" % (timestamp, node._id)
+        batch_dir = os.path.join(node.base_dir, "batch")
     if not os.path.exists(batch_dir):
         os.makedirs(batch_dir)
-    pkl_file = os.path.join(batch_dir, 'node_%s.pklz' % suffix)
+    pkl_file = os.path.join(batch_dir, "node_%s.pklz" % suffix)
     savepkl(pkl_file, dict(node=node, updatehash=updatehash))
     mpl_backend = node.config["execution"]["matplotlib_backend"]
     # create python script to load and trap exception
@@ -110,7 +125,13 @@ except ImportError:
     can_import_matplotlib = False
     pass
 
+import os
+value = os.environ.get('NIPYPE_NO_ET', None)
+if value is None:
+    # disable ET for any submitted job
+    os.environ['NIPYPE_NO_ET'] = "1"
 from nipype import config, logging
+
 from nipype.utils.filemanip import loadpkl, savepkl
 from socket import gethostname
 from traceback import format_exception
@@ -119,8 +140,7 @@ pklfile = '%s'
 batchdir = '%s'
 from nipype.utils.filemanip import loadpkl, savepkl
 try:
-    if not sys.version_info < (2, 7):
-        from collections import OrderedDict
+    from collections import OrderedDict
     config_dict=%s
     config.update_config(config_dict)
     ## Only configure matplotlib if it was successfully imported,
@@ -159,7 +179,7 @@ except Exception as e:
     raise Exception(e)
 """
     cmdstr = cmdstr % (mpl_backend, pkl_file, batch_dir, node.config, suffix)
-    pyscript = os.path.join(batch_dir, 'pyscript_%s.py' % suffix)
-    with open(pyscript, 'wt') as fp:
+    pyscript = os.path.join(batch_dir, "pyscript_%s.py" % suffix)
+    with open(pyscript, "wt") as fp:
         fp.writelines(cmdstr)
     return pyscript
