@@ -3,9 +3,6 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Miscellaneous file manipulation functions
 """
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-
 import sys
 import pickle
 import errno
@@ -20,28 +17,42 @@ import re
 import shutil
 import contextlib
 import posixpath
+from pathlib import Path
 import simplejson as json
-import numpy as np
+from time import sleep, time
 
-from builtins import str, bytes, open
-
-from .. import logging, config
+from .. import logging, config, __version__ as version
 from .misc import is_container
-from future import standard_library
-standard_library.install_aliases()
 
-fmlogger = logging.getLogger('nipype.utils')
+fmlogger = logging.getLogger("nipype.utils")
 
-related_filetype_sets = [
-    ('.hdr', '.img', '.mat'),
-    ('.nii', '.mat'),
-    ('.BRIK', '.HEAD'),
-]
+related_filetype_sets = [(".hdr", ".img", ".mat"), (".nii", ".mat"), (".BRIK", ".HEAD")]
 
-PY3 = sys.version_info[0] >= 3
 
-class FileNotFoundError(Exception):
-    pass
+def _resolve_with_filenotfound(path, **kwargs):
+    """ Raise FileNotFoundError instead of OSError """
+    try:
+        return path.resolve(**kwargs)
+    except OSError as e:
+        if isinstance(e, FileNotFoundError):
+            raise
+        raise FileNotFoundError(str(path))
+
+
+def path_resolve(path, strict=False):
+    try:
+        return _resolve_with_filenotfound(path, strict=strict)
+    except TypeError:  # PY35
+        pass
+
+    path = path.absolute()
+    if strict or path.exists():
+        return _resolve_with_filenotfound(path)
+
+    # This is a hacky shortcut, using path.absolute() unmodified
+    # In cases where the existing part of the path contains a
+    # symlink, different results will be produced
+    return path
 
 
 def split_filename(fname):
@@ -84,8 +95,7 @@ def split_filename(fname):
     ext = None
     for special_ext in special_extensions:
         ext_len = len(special_ext)
-        if (len(fname) > ext_len) and \
-                (fname[-ext_len:].lower() == special_ext.lower()):
+        if (len(fname) > ext_len) and (fname[-ext_len:].lower() == special_ext.lower()):
             ext = fname[-ext_len:]
             fname = fname[:-ext_len]
             break
@@ -95,64 +105,7 @@ def split_filename(fname):
     return pth, fname, ext
 
 
-def to_str(value):
-    """
-    Manipulates ordered dicts before they are hashed (Py2/3 compat.)
-
-    """
-    if sys.version_info[0] > 2:
-        retval = str(value)
-    else:
-        retval = to_str_py27(value)
-    return retval
-
-
-def to_str_py27(value):
-    """
-    Encode dictionary for python 2
-    """
-
-    if isinstance(value, dict):
-        entry = '{}: {}'.format
-        retval = '{'
-        for key, val in list(value.items()):
-            if len(retval) > 1:
-                retval += ', '
-            kenc = repr(key)
-            if kenc.startswith(("u'", 'u"')):
-                kenc = kenc[1:]
-            venc = to_str_py27(val)
-            if venc.startswith(("u'", 'u"')):
-                venc = venc[1:]
-            retval += entry(kenc, venc)
-        retval += '}'
-        return retval
-
-    istuple = isinstance(value, tuple)
-    if isinstance(value, (tuple, list)):
-        retval = '(' if istuple else '['
-        nels = len(value)
-        for i, v in enumerate(value):
-            venc = to_str_py27(v)
-            if venc.startswith(("u'", 'u"')):
-                venc = venc[1:]
-            retval += venc
-
-            if i < nels - 1:
-                retval += ', '
-
-        if istuple and nels == 1:
-            retval += ','
-        retval += ')' if istuple else ']'
-        return retval
-
-    retval = repr(value).decode()
-    if retval.startswith(("u'", 'u"')):
-        retval = retval[1:]
-    return retval
-
-
-def fname_presuffix(fname, prefix='', suffix='', newpath=None, use_ext=True):
+def fname_presuffix(fname, prefix="", suffix="", newpath=None, use_ext=True):
     """Manipulates path and name of input filename
 
     Parameters
@@ -186,7 +139,7 @@ def fname_presuffix(fname, prefix='', suffix='', newpath=None, use_ext=True):
     """
     pth, fname, ext = split_filename(fname)
     if not use_ext:
-        ext = ''
+        ext = ""
 
     # No need for isdefined: bool(Undefined) evaluates to False
     if newpath:
@@ -194,7 +147,7 @@ def fname_presuffix(fname, prefix='', suffix='', newpath=None, use_ext=True):
     return op.join(pth, prefix + fname + suffix + ext)
 
 
-def fnames_presuffix(fnames, prefix='', suffix='', newpath=None, use_ext=True):
+def fnames_presuffix(fnames, prefix="", suffix="", newpath=None, use_ext=True):
     """Calls fname_presuffix for a list of files.
     """
     f2 = []
@@ -208,7 +161,7 @@ def hash_rename(filename, hashvalue):
     and sets path to output_directory
     """
     path, name, ext = split_filename(filename)
-    newfilename = ''.join((name, '_0x', hashvalue, ext))
+    newfilename = "".join((name, "_0x", hashvalue, ext))
     return op.join(path, newfilename)
 
 
@@ -217,15 +170,14 @@ def check_forhash(filename):
     if isinstance(filename, list):
         filename = filename[0]
     path, name = op.split(filename)
-    if re.search('(_0x[a-z0-9]{32})', name):
-        hashvalue = re.findall('(_0x[a-z0-9]{32})', name)
+    if re.search("(_0x[a-z0-9]{32})", name):
+        hashvalue = re.findall("(_0x[a-z0-9]{32})", name)
         return True, hashvalue
     else:
         return False, None
 
 
-def hash_infile(afile, chunk_len=8192, crypto=hashlib.md5,
-                raise_notfound=False):
+def hash_infile(afile, chunk_len=8192, crypto=hashlib.md5, raise_notfound=False):
     """
     Computes hash of a file using 'crypto' module
 
@@ -249,7 +201,7 @@ def hash_infile(afile, chunk_len=8192, crypto=hashlib.md5,
         return None
 
     crypto_obj = crypto()
-    with open(afile, 'rb') as fp:
+    with open(afile, "rb") as fp:
         while True:
             data = fp.read(chunk_len)
             if not data:
@@ -284,19 +236,19 @@ def _parse_mount_table(exit_code, output):
     #                          <PATH>^^^^      ^^^^^<FSTYPE>
     # OSX mount example:    /dev/disk2 on / (hfs, local, journaled)
     #                               <PATH>^  ^^^<FSTYPE>
-    pattern = re.compile(r'.*? on (/.*?) (?:type |\()([^\s,\)]+)')
+    pattern = re.compile(r".*? on (/.*?) (?:type |\()([^\s,\)]+)")
 
     # Keep line and match for error reporting (match == None on failure)
     # Ignore empty lines
-    matches = [(l, pattern.match(l))
-               for l in output.strip().splitlines() if l]
+    matches = [(l, pattern.match(l)) for l in output.strip().splitlines() if l]
 
     # (path, fstype) tuples, sorted by path length (longest first)
-    mount_info = sorted((match.groups() for _, match in matches
-                         if match is not None),
-                        key=lambda x: len(x[0]), reverse=True)
-    cifs_paths = [path for path, fstype in mount_info
-                  if fstype.lower() == 'cifs']
+    mount_info = sorted(
+        (match.groups() for _, match in matches if match is not None),
+        key=lambda x: len(x[0]),
+        reverse=True,
+    )
+    cifs_paths = [path for path, fstype in mount_info if fstype.lower() == "cifs"]
 
     # Report failures as warnings
     for line, match in matches:
@@ -304,7 +256,8 @@ def _parse_mount_table(exit_code, output):
             fmlogger.debug("Cannot parse mount line: '%s'", line)
 
     return [
-        mount for mount in mount_info
+        mount
+        for mount in mount_info
         if any(mount[0].startswith(path) for path in cifs_paths)
     ]
 
@@ -327,7 +280,8 @@ _cifs_table = _generate_cifs_table()
 
 
 def on_cifs(fname):
-    """ Checks whether a file path is on a CIFS filesystem mounted in a POSIX
+    """
+    Checks whether a file path is on a CIFS filesystem mounted in a POSIX
     host (i.e., has the ``mount`` command).
 
     On Windows, Docker mounts host directories into containers through CIFS
@@ -335,24 +289,27 @@ def on_cifs(fname):
     the CIFS driver exposes to the OS as symlinks.
     We have found that under concurrent access to the filesystem, this feature
     can result in failures to create or read recently-created symlinks,
-    leading to inconsistent behavior and ``FileNotFoundError``s.
+    leading to inconsistent behavior and ``FileNotFoundError``.
 
     This check is written to support disabling symlinks on CIFS shares.
+
     """
     # Only the first match (most recent parent) counts
     for fspath, fstype in _cifs_table:
         if fname.startswith(fspath):
-            return fstype == 'cifs'
+            return fstype == "cifs"
     return False
 
 
-def copyfile(originalfile,
-             newfile,
-             copy=False,
-             create_new=False,
-             hashmethod=None,
-             use_hardlink=False,
-             copy_related_files=True):
+def copyfile(
+    originalfile,
+    newfile,
+    copy=False,
+    create_new=False,
+    hashmethod=None,
+    use_hardlink=False,
+    copy_related_files=True,
+):
     """Copy or link ``originalfile`` to ``newfile``.
 
     If ``use_hardlink`` is True, and the file can be hard-linked, then a
@@ -389,7 +346,7 @@ def copyfile(originalfile,
     if create_new:
         while op.exists(newfile):
             base, fname, ext = split_filename(newfile)
-            s = re.search('_c[0-9]{4,4}$', fname)
+            s = re.search("_c[0-9]{4,4}$", fname)
             i = 0
             if s:
                 i = int(s.group()[2:]) + 1
@@ -399,7 +356,7 @@ def copyfile(originalfile,
             newfile = base + os.sep + fname + ext
 
     if hashmethod is None:
-        hashmethod = config.get('execution', 'hash_method').lower()
+        hashmethod = config.get("execution", "hash_method").lower()
 
     # Don't try creating symlinks on CIFS
     if copy is False and on_cifs(newfile):
@@ -419,26 +376,33 @@ def copyfile(originalfile,
     keep = False
     if op.lexists(newfile):
         if op.islink(newfile):
-            if all((os.readlink(newfile) == op.realpath(originalfile),
-                    not use_hardlink, not copy)):
+            if all(
+                (
+                    os.readlink(newfile) == op.realpath(originalfile),
+                    not use_hardlink,
+                    not copy,
+                )
+            ):
                 keep = True
         elif posixpath.samefile(newfile, originalfile):
             keep = True
         else:
-            if hashmethod == 'timestamp':
+            if hashmethod == "timestamp":
                 hashfn = hash_timestamp
-            elif hashmethod == 'content':
+            elif hashmethod == "content":
                 hashfn = hash_infile
             else:
                 raise AttributeError("Unknown hash method found:", hashmethod)
             newhash = hashfn(newfile)
-            fmlogger.debug('File: %s already exists,%s, copy:%d', newfile,
-                           newhash, copy)
+            fmlogger.debug(
+                "File: %s already exists,%s, copy:%d", newfile, newhash, copy
+            )
             orighash = hashfn(originalfile)
             keep = newhash == orighash
         if keep:
-            fmlogger.debug('File: %s already exists, not overwriting, copy:%d',
-                           newfile, copy)
+            fmlogger.debug(
+                "File: %s already exists, not overwriting, copy:%d", newfile, copy
+            )
         else:
             os.unlink(newfile)
 
@@ -449,7 +413,7 @@ def copyfile(originalfile,
     # ~hardlink & ~symlink => copy
     if not keep and use_hardlink:
         try:
-            fmlogger.debug('Linking File: %s->%s', newfile, originalfile)
+            fmlogger.debug("Linking File: %s->%s", newfile, originalfile)
             # Use realpath to avoid hardlinking symlinks
             os.link(op.realpath(originalfile), newfile)
         except OSError:
@@ -457,9 +421,9 @@ def copyfile(originalfile,
         else:
             keep = True
 
-    if not keep and not copy and os.name == 'posix':
+    if not keep and not copy and os.name == "posix":
         try:
-            fmlogger.debug('Symlinking File: %s->%s', newfile, originalfile)
+            fmlogger.debug("Symlinking File: %s->%s", newfile, originalfile)
             os.symlink(originalfile, newfile)
         except OSError:
             copy = True  # Disable symlink for associated files
@@ -468,15 +432,17 @@ def copyfile(originalfile,
 
     if not keep:
         try:
-            fmlogger.debug('Copying File: %s->%s', newfile, originalfile)
+            fmlogger.debug("Copying File: %s->%s", newfile, originalfile)
             shutil.copyfile(originalfile, newfile)
         except shutil.Error as e:
-            fmlogger.warning(e.message)
+            fmlogger.warning(str(e))
 
     # Associated files
     if copy_related_files:
-        related_file_pairs = (get_related_files(f, include_this_file=False)
-                              for f in (originalfile, newfile))
+        related_file_pairs = (
+            get_related_files(f, include_this_file=False)
+            for f in (originalfile, newfile)
+        )
         for alt_ofile, alt_nfile in zip(*related_file_pairs):
             if op.exists(alt_ofile):
                 copyfile(
@@ -485,7 +451,8 @@ def copyfile(originalfile,
                     copy,
                     hashmethod=hashmethod,
                     use_hardlink=use_hardlink,
-                    copy_related_files=False)
+                    copy_related_files=False,
+                )
 
     return newfile
 
@@ -538,9 +505,7 @@ def copyfiles(filelist, dest, copy=False, create_new=False):
     newfiles = []
     for i, f in enumerate(ensure_list(filelist)):
         if isinstance(f, list):
-            newfiles.insert(i,
-                            copyfiles(
-                                f, dest, copy=copy, create_new=create_new))
+            newfiles.insert(i, copyfiles(f, dest, copy=copy, create_new=create_new))
         else:
             if len(outfiles) > 1:
                 destfile = outfiles[i]
@@ -585,9 +550,9 @@ def check_depends(targets, dependencies):
     """
     tgts = ensure_list(targets)
     deps = ensure_list(dependencies)
-    return all(map(op.exists, tgts)) and \
-        min(map(op.getmtime, tgts)) > \
-        max(list(map(op.getmtime, deps)) + [0])
+    return all(map(op.exists, tgts)) and min(map(op.getmtime, tgts)) > max(
+        list(map(op.getmtime, deps)) + [0]
+    )
 
 
 def save_json(filename, data):
@@ -601,9 +566,7 @@ def save_json(filename, data):
         Dictionary to save in json file.
 
     """
-    mode = 'w'
-    if sys.version_info[0] < 3:
-        mode = 'wb'
+    mode = "w"
     with open(filename, mode) as fp:
         json.dump(data, fp, sort_keys=True, indent=4)
 
@@ -622,77 +585,104 @@ def load_json(filename):
 
     """
 
-    with open(filename, 'r') as fp:
+    with open(filename, "r") as fp:
         data = json.load(fp)
     return data
 
 
 def loadcrash(infile, *args):
-    if infile.endswith('pkl') or infile.endswith('pklz'):
-        return loadpkl(infile, versioning=True)
+    if infile.endswith("pkl") or infile.endswith("pklz"):
+        return loadpkl(infile)
     else:
-        raise ValueError('Only pickled crashfiles are supported')
+        raise ValueError("Only pickled crashfiles are supported")
 
 
-def loadpkl(infile, versioning=False):
-    """Load a zipped or plain cPickled file
-    """
-    fmlogger.debug('Loading pkl: %s', infile)
-    if infile.endswith('pklz'):
-        pkl_file = gzip.open(infile, 'rb')
-    else:
-        pkl_file = open(infile, 'rb')
+def loadpkl(infile):
+    """Load a zipped or plain cPickled file."""
+    infile = Path(infile)
+    fmlogger.debug("Loading pkl: %s", infile)
+    pklopen = gzip.open if infile.suffix == ".pklz" else open
 
-    if versioning:
-        pkl_metadata = {}
+    t = time()
+    timeout = float(config.get("execution", "job_finished_timeout"))
+    timed_out = True
+    while (time() - t) < timeout:
+        if infile.exists():
+            timed_out = False
+            break
+        fmlogger.debug("'{}' missing; waiting 2s".format(infile))
+        sleep(2)
+    if timed_out:
+        error_message = (
+            "Result file {0} expected, but "
+            "does not exist after ({1}) "
+            "seconds.".format(infile, timeout)
+        )
+        raise IOError(error_message)
 
-        # Look if pkl file contains version file
+    with pklopen(str(infile), "rb") as pkl_file:
+        pkl_contents = pkl_file.read()
+
+    pkl_metadata = None
+
+    # Look if pkl file contains version metadata
+    idx = pkl_contents.find(b"\n")
+    if idx >= 0:
         try:
-            pkl_metadata_line = pkl_file.readline()
-            pkl_metadata = json.loads(pkl_metadata_line)
-        except:
+            pkl_metadata = json.loads(pkl_contents[:idx])
+        except (UnicodeDecodeError, json.JSONDecodeError):
             # Could not get version info
-            pkl_file.seek(0)
+            pass
+        else:
+            # On success, skip JSON metadata
+            pkl_contents = pkl_contents[idx + 1 :]
 
+    # Pickle files may contain relative paths that must be resolved relative
+    # to the working directory, so use indirectory while attempting to load
+    unpkl = None
     try:
-        try:
-            unpkl = pickle.load(pkl_file)
-        except UnicodeDecodeError:
-            unpkl = pickle.load(pkl_file, fix_imports=True, encoding='utf-8')
-
-        return unpkl
-
+        with indirectory(infile.parent):
+            unpkl = pickle.loads(pkl_contents)
+    except UnicodeDecodeError:
+        # Was this pickle created with Python 2.x?
+        with indirectory(infile.parent):
+            unpkl = pickle.loads(pkl_contents, fix_imports=True, encoding="utf-8")
+        fmlogger.info("Successfully loaded pkl in compatibility mode.")
     # Unpickling problems
     except Exception as e:
-        if not versioning:
-            raise e
-
-        from nipype import __version__ as version
-
-        if 'version' in pkl_metadata:
-            if pkl_metadata['version'] != version:
-                fmlogger.error('Your Nipype version is: %s',
-                               version)
-                fmlogger.error('Nipype version of the pkl is: %s',
-                               pkl_metadata['version'])
-        else:
-            fmlogger.error('No metadata was found in the pkl file.')
-            fmlogger.error('Make sure that you are using the same Nipype'
-                           'version from the generated pkl.')
-
+        if pkl_metadata and "version" in pkl_metadata:
+            if pkl_metadata["version"] != version:
+                fmlogger.error(
+                    """\
+Attempted to open a results file generated by Nipype version %s, \
+with an incompatible Nipype version (%s)""",
+                    pkl_metadata["version"],
+                    version,
+                )
+                raise e
+        fmlogger.warning(
+            """\
+No metadata was found in the pkl file. Make sure you are currently using \
+the same Nipype version from the generated pkl."""
+        )
         raise e
 
+    if unpkl is None:
+        raise ValueError("Loading %s resulted in None." % infile)
+
+    return unpkl
+
 
 def crash2txt(filename, record):
     """ Write out plain text crash file """
-    with open(filename, 'w') as fp:
-        if 'node' in record:
-            node = record['node']
-            fp.write('Node: {}\n'.format(node.fullname))
-            fp.write('Working directory: {}\n'.format(node.output_dir()))
-            fp.write('\n')
-            fp.write('Node inputs:\n{}\n'.format(node.inputs))
-        fp.write(''.join(record['traceback']))
+    with open(filename, "w") as fp:
+        if "node" in record:
+            node = record["node"]
+            fp.write("Node: {}\n".format(node.fullname))
+            fp.write("Working directory: {}\n".format(node.output_dir()))
+            fp.write("\n")
+            fp.write("Node inputs:\n{}\n".format(node.inputs))
+        fp.write("".join(record["traceback"]))
 
 
 def read_stream(stream, logger=None, encoding=None):
@@ -705,53 +695,53 @@ def read_stream(stream, logger=None, encoding=None):
 
 
     """
-    default_encoding = encoding or locale.getdefaultlocale()[1] or 'UTF-8'
+    default_encoding = encoding or locale.getdefaultlocale()[1] or "UTF-8"
     logger = logger or fmlogger
     try:
         out = stream.decode(default_encoding)
     except UnicodeDecodeError as err:
-        out = stream.decode(default_encoding, errors='replace')
-        logger.warning('Error decoding string: %s', err)
+        out = stream.decode(default_encoding, errors="replace")
+        logger.warning("Error decoding string: %s", err)
     return out.splitlines()
 
 
 def savepkl(filename, record, versioning=False):
-    if filename.endswith('pklz'):
-        pkl_file = gzip.open(filename, 'wb')
-    else:
-        pkl_file = open(filename, 'wb')
+    from io import BytesIO
 
-    if versioning:
-        from nipype import __version__ as version
-        metadata = json.dumps({'version': version})
+    with BytesIO() as f:
+        if versioning:
+            metadata = json.dumps({"version": version})
+            f.write(metadata.encode("utf-8"))
+            f.write("\n".encode("utf-8"))
+        pickle.dump(record, f)
+        content = f.getvalue()
 
-        pkl_file.write(metadata.encode('utf-8'))
-        pkl_file.write('\n'.encode('utf-8'))
-
-    pickle.dump(record, pkl_file)
-    pkl_file.close()
+    pkl_open = gzip.open if filename.endswith(".pklz") else open
+    tmpfile = filename + ".tmp"
+    with pkl_open(tmpfile, "wb") as pkl_file:
+        pkl_file.write(content)
+    os.rename(tmpfile, filename)
 
 
-rst_levels = ['=', '-', '~', '+']
+rst_levels = ["=", "-", "~", "+"]
 
 
 def write_rst_header(header, level=0):
-    return '\n'.join(
-        (header, ''.join([rst_levels[level] for _ in header]))) + '\n\n'
+    return "\n".join((header, "".join([rst_levels[level] for _ in header]))) + "\n\n"
 
 
-def write_rst_list(items, prefix=''):
+def write_rst_list(items, prefix=""):
     out = []
-    for item in items:
-        out.append('{} {}'.format(prefix, str(item)))
-    return '\n'.join(out) + '\n\n'
+    for item in ensure_list(items):
+        out.append("{} {}".format(prefix, str(item)))
+    return "\n".join(out) + "\n\n"
 
 
-def write_rst_dict(info, prefix=''):
+def write_rst_dict(info, prefix=""):
     out = []
     for key, value in sorted(info.items()):
-        out.append('{}* {} : {}'.format(prefix, key, str(value)))
-    return '\n'.join(out) + '\n\n'
+        out.append("{}* {} : {}".format(prefix, key, str(value)))
+    return "\n".join(out) + "\n\n"
 
 
 def dist_is_editable(dist):
@@ -765,37 +755,12 @@ def dist_is_editable(dist):
     # Borrowed from `pip`'s' API
     """
     for path_item in sys.path:
-        egg_link = op.join(path_item, dist + '.egg-link')
+        egg_link = op.join(path_item, dist + ".egg-link")
         if op.isfile(egg_link):
             return True
     return False
 
 
-def makedirs(path, exist_ok=False):
-    """
-    Create path, if it doesn't exist.
-
-    Parameters
-    ----------
-    path : output directory to create
-
-    """
-    if not exist_ok:  # The old makedirs
-        os.makedirs(path)
-        return path
-
-    # this odd approach deals with concurrent directory cureation
-    if not op.exists(op.abspath(path)):
-        fmlogger.debug("Creating directory %s", path)
-        try:
-            os.makedirs(path)
-        except OSError:
-            fmlogger.debug("Problem creating directory %s", path)
-            if not op.exists(path):
-                raise OSError('Could not create directory %s' % path)
-    return path
-
-
 def emptydirs(path, noexist_ok=False):
     """
     Empty an existing directory, without deleting it. Do not
@@ -820,16 +785,38 @@ def emptydirs(path, noexist_ok=False):
         elcont = os.listdir(path)
         if ex.errno == errno.ENOTEMPTY and not elcont:
             fmlogger.warning(
-                'An exception was raised trying to remove old %s, but the path'
-                ' seems empty. Is it an NFS mount?. Passing the exception.',
-                path)
+                "An exception was raised trying to remove old %s, but the path"
+                " seems empty. Is it an NFS mount?. Passing the exception.",
+                path,
+            )
         elif ex.errno == errno.ENOTEMPTY and elcont:
-            fmlogger.debug('Folder %s contents (%d items).', path, len(elcont))
+            fmlogger.debug("Folder %s contents (%d items).", path, len(elcont))
             raise ex
         else:
             raise ex
 
-    makedirs(path)
+    os.makedirs(path)
+
+
+def silentrm(filename):
+    """
+    Equivalent to ``rm -f``, returns ``False`` if the file did not
+    exist.
+
+    Parameters
+    ----------
+
+    filename : str
+        file to be deleted
+
+    """
+    try:
+        os.remove(filename)
+    except OSError as e:
+        if e.errno != errno.ENOENT:
+            raise
+        return False
+    return True
 
 
 def which(cmd, env=None, pathext=None):
@@ -843,34 +830,17 @@ def which(cmd, env=None, pathext=None):
     """
 
     if pathext is None:
-        pathext = os.getenv('PATHEXT', '').split(os.pathsep)
-        pathext.insert(0, '')
+        pathext = os.getenv("PATHEXT", "").split(os.pathsep)
+        pathext.insert(0, "")
 
     path = os.getenv("PATH", os.defpath)
-    if env and 'PATH' in env:
+    if env and "PATH" in env:
         path = env.get("PATH")
 
-    if sys.version_info >= (3, 3):
-        for ext in pathext:
-            filename = shutil.which(cmd + ext, path=path)
-            if filename:
-                return filename
-        return None
-
-    def isexec(path):
-        return os.path.isfile(path) and os.access(path, os.X_OK)
-
     for ext in pathext:
-        extcmd = cmd + ext
-        fpath, fname = os.path.split(extcmd)
-        if fpath:
-            if isexec(extcmd):
-                return extcmd
-        else:
-            for directory in path.split(os.pathsep):
-                filename = op.join(directory, extcmd)
-                if isexec(filename):
-                    return filename
+        filename = shutil.which(cmd + ext, path=path)
+        if filename:
+            return filename
     return None
 
 
@@ -881,32 +851,28 @@ def get_dependencies(name, environ):
 
     """
     command = None
-    if sys.platform == 'darwin':
-        command = 'otool -L `which %s`' % name
-    elif 'linux' in sys.platform:
-        command = 'ldd `which %s`' % name
+    if sys.platform == "darwin":
+        command = "otool -L `which %s`" % name
+    elif "linux" in sys.platform:
+        command = "ldd `which %s`" % name
     else:
-        return 'Platform %s not supported' % sys.platform
+        return "Platform %s not supported" % sys.platform
 
     deps = None
     try:
         proc = sp.Popen(
-            command,
-            stdout=sp.PIPE,
-            stderr=sp.PIPE,
-            shell=True,
-            env=environ)
+            command, stdout=sp.PIPE, stderr=sp.PIPE, shell=True, env=environ
+        )
         o, e = proc.communicate()
         deps = o.rstrip()
     except Exception as ex:
-        deps = '"%s" failed' % command
-        fmlogger.warning('Could not get dependencies of %s. Error:\n%s',
-                         name, ex.message)
+        deps = f'{command!r} failed'
+        fmlogger.warning(f"Could not get dependencies of {name}s. Error:\n{ex}")
     return deps
 
 
 def canonicalize_env(env):
-    """Windows requires that environment be dicts with bytes as keys and values
+    """Windows requires that environment be dicts with str as keys and values
     This function converts any unicode entries for Windows only, returning the
     dictionary untouched in other environments.
 
@@ -918,24 +884,18 @@ def canonicalize_env(env):
     Returns
     -------
     env : dict
-        Windows: environment dictionary with bytes keys and values
+        Windows: environment dictionary with str keys and values
         Other: untouched input ``env``
     """
-    if os.name != 'nt':
+    if os.name != "nt":
         return env
 
-    # convert unicode to string for python 2
-    if not PY3:
-        from future.utils import bytes_to_native_str
     out_env = {}
     for key, val in env.items():
-        if not isinstance(key, bytes):
-            key = key.encode('utf-8')
-        if not isinstance(val, bytes):
-            val = val.encode('utf-8')
-        if not PY3:
-            key = bytes_to_native_str(key)
-            val = bytes_to_native_str(val)
+        if not isinstance(key, str):
+            key = key.decode("utf-8")
+        if not isinstance(val, str):
+            val = val.decode("utf-8")
         out_env[key] = val
     return out_env
 
@@ -958,11 +918,13 @@ def relpath(path, start=None):
         unc_path, rest = op.splitunc(path)
         unc_start, rest = op.splitunc(start)
         if bool(unc_path) ^ bool(unc_start):
-            raise ValueError(("Cannot mix UNC and non-UNC paths "
-                              "(%s and %s)") % (path, start))
+            raise ValueError(
+                ("Cannot mix UNC and non-UNC paths " "(%s and %s)") % (path, start)
+            )
         else:
-            raise ValueError("path is on drive %s, start on drive %s" %
-                             (path_list[0], start_list[0]))
+            raise ValueError(
+                "path is on drive %s, start on drive %s" % (path_list[0], start_list[0])
+            )
     # Work out how much of the filepath is shared by start and path.
     for i in range(min(len(start_list), len(path_list))):
         if start_list[i].lower() != path_list[i].lower():
@@ -979,7 +941,7 @@ def relpath(path, start=None):
 @contextlib.contextmanager
 def indirectory(path):
     cwd = os.getcwd()
-    os.chdir(path)
+    os.chdir(str(path))
     try:
         yield
     finally:
