@@ -3,6 +3,7 @@
 """
 
 from builtins import map
+
 # Library imports
 import os
 import sys
@@ -29,10 +30,9 @@ def sh(cmd):
 
 def compile_tree():
     """Compile all Python files below current directory."""
-    vstr = '.'.join(map(str, sys.version_info[:2]))
-    stat = os.system('python %s/lib/python%s/compileall.py .' %
-                     (sys.prefix, vstr))
+    vstr = ".".join(map(str, sys.version_info[:2]))
+    stat = os.system("%s %s/lib/python%s/compileall.py ." % (sys.executable, sys.prefix, vstr))
     if stat:
-        msg = '*** ERROR: Some Python files in tree do NOT compile! ***\n'
-        msg += 'See messages above for the actual file that produced it.\n'
+        msg = "*** ERROR: Some Python files in tree do NOT compile! ***\n"
+        msg += "See messages above for the actual file that produced it.\n"
         raise SystemExit(msg)
