@@ -12,7 +12,8 @@
 set -u         # Treat unset variables as an error when substituting.
 set -x         # Print command traces before executing command.
 
-CHANGES=../doc/changelog/1.X.X-changelog
+ROOT=$( git rev-parse --show-toplevel )
+CHANGES=$ROOT/doc/changelog/1.X.X-changelog.rst
 
 # Check whether the Upcoming release header is present
 head -1 $CHANGES | grep -q Upcoming
@@ -22,7 +23,10 @@ UPCOMING=$?
 HEADER="$1 ($(date '+%B %d, %Y'))"
 echo $HEADER >> newchanges
 echo $( printf "%${#HEADER}s" | tr " " "=" ) >> newchanges
-echo "" >> newchanges
+
+if [[ "x$2" != "x" ]]; then
+	echo "(\`Full changelog <https://github.com/nipy/nipype/milestone/$2?closed=1>\`__)" >> newchanges
+fi
 
 # Search for PRs since previous release
 git log --grep="Merge pull request" `git describe --tags --abbrev=0`..HEAD --pretty='format:  * %b %s' | sed  's+Merge pull request \#\([^\d]*\)\ from\ .*+(https://github.com/nipy/nipype/pull/\1)+' >> newchanges
